// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// This code specify country-specific variables.  
// This version December 10, 2019
// Serdar Ozkan and Sergio Salgado
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

// PLEASE DO NOT CHANGE VALUES FRM LINE 9 TO 18. IF NEEDS TO BE CHANGED, CONTACT Ozkan/Salgado

set more off
set matsize 500
set linesize 255
version 13  // This program uses Stata version 13. 

global begin_age = 25 		// Starting age
global end_age = 55			// Ending age
global base_price = 2018	// The base year nominal values are converted to real. 
global winsor=99.999999		// The values above this percentile are going to be set to this percentile. 
global noise=0.0			// Noise added to income. See line 112 in 1_Gen_Base_Sample.do


// PLEASE MAKE THE APPROPRIATE CHANGES BELOW. 

global unix=1  // Please change this to 1 if you run stata on Unix or Mac

global wide=0  // Please change this to 1 if your raw data is in wide format; 0 if long. 

if($unix==1){
	global sep="/"
}
else{
	global sep="\"
}
// If there are missing observations for earnings between $begin_age and $end_age
// set the below global to 1. Otherwise, the code will convert all missing earnings
// observations to zero.
global miss_earn=0   /*there is gap in years*/

//Please change the below to the name of the actual data set
global datafile="$maindir${sep}dta${sep}t1pmf_all" 

// Define the variable names in your dataset.
global personid_var="casenum2018" 	// The variable name for person identity number.
global male_var="male" 		// The variable name for gender: 1 if male, 0 o/w.
global yob_var="birth_year_h" 	// The variable name for year of birth.
global yod_var="death_year_h" 		// The variable name for year of death.
global educ_var="edu" 		// The variable name for year of death.
global labor_var="earn" // The variable name for total annual labor earnings from all jobs during the year.  
global year_var="year" 		// The variable name for year if the data is in long format


// Define these variables for your dataset
global yrfirst = 1983 		// First year in the dataset 
global yrlast =  2016 		// Last year in the dataset

global kyear = 5
	// This controls the years for which the empirical densities will be calculated.
	// The densisity is calculated every mod(year/kyear) == 0. Set to 1 if 
	// every year is needed (If need changes, contact  Ozkan/Salgado)
	
global nquantiles = 40
	// Number of quantiles used in the statistics conditioning on permanent income
	// One additional quintile will be added at the top for a total of 41 (see Guidelines)
		
global nquantilesalt = 40
	// Number of quantiles used in the statistics conditioning on the alternative measure of permanent income
	
global nquantilestran = 10 
	// Number of quantiles used in the age transition matrix
	
global qpercent = 99	
	// Top percentile for which the change in top-share will be calculated. 
	// In this case 99 implies top 1%. 
	// Calculations are made using  Matthieu Gomez's paper
	
global mergecohort = 2
	// Number of cohorts to be merged to prevent too few observations in year/age cells 
	
global hetgroup = `"male age educ "male age" "male educ" "male educ age" "' 
	// Define heterogenous groups for which time series stats will be calculated 

// Price index for converting nominal values to real, e.g., the PCE for the US.  
// IMPORTANT: Please set the LOCAL CPI starting from year ${yrfirst} and ending in ${yrlast}.

global cpi2018 = 133.4		// Set the value of the CPI in 2018. 
matrix cpimat = /*  CPI between ${yrfirst}  and ${yrlast}
 */ (58.1, 60.6, 63, 65.6, 68.5, 71.2, 74.8, 78.4, 82.8, 84, 85.6, 85.7, 87.6, 88.9, 90.4, /*
  */  91.3, 92.9, 95.4, 97.8, 100, 102.8, 104.7, 107, 109.1, 111.5, 114.1, 114.4,  /*
  */   116.5, 119.9, 121.7, 122.8, 125.2, 126.6, 128.4 )'
  
matrix cpimat = cpimat/${cpi2018}

global exrate2018 = 1.2957		// Set the value the exchange rate from LC to 1US$ in 2018 (e.g. 1US$ = $(exrate2018) LC)
matrix exrate = /*  Nominal average exchange rate from FRED between ${yrfirst}  and ${yrlast} (LC per dollar)
*/ (1.2324119, 1.2950656, 1.3655074, 1.3894711, 1.3259826, 1.2307009, 1.1839721, 1.1667737, /*
*/	1.1457258, 1.2087229, 1.2900879, 1.3656734, 1.3724455, 1.3635216,  1.384598, 1.4835052, /*
*/	1.4857049,  1.4853941, 1.5488398, 1.5703428, 1.4010146, 1.3012816, 1.2114052, 1.1343447, /*
 */  1.0740457, 1.0670869, 1.1415354, 1.0301127, .98925817, .99936473, 1.0301374, 1.1047472, 1.2787862, /*
 */	1.3256152)'


// Define years for recession bars/ These will be used to generate a variable called rece used in the plots
 /*global receyears = "1993,1993,1995,2002,2003,2004,2009,2010,2015" */
 /*canadian recession */
 global receyears = "1986,1989,1990,1991,2001,2003,2008,2009,2015,2016" 
 global receyears2 = "1983,1986,1987,1988,1998,2000,2005,2006,2012,2013"
// Define the year that will be use for normalization. 
global normyear = ${yrfirst}


/*DO NOT CHANGE THIS SECTION**********************************************
THIS SECTION DEFINES THE REAL EXCHANGE CHANGE USING THE LOCAL AND US CPI
*/
global cpi2018us = 108.231		// DO NOT CHANGE. This is the US PCE  
								// Annual average from https://fred.stlouisfed.org/series/PCEPI#0
matrix cpimatus = /*  PCE between 1970  and 2018
*/ (20.951, 21.841, 22.586, 23.802, 26.280, 28.470, 30.032, 31.986, 34.211, 37.250,  /*
*/ 41.262, 44.959, 47.456, 49.475, 51.343, 53.134, 54.290, 55.964, 58.150, 60.690,  /*
*/ 63.355, 65.473, 67.218, 68.892, 70.330, 71.811, 73.346, 74.623, 75.216, 76.338, /*
*/ 78.235, 79.738, 80.789, 82.358, 84.411, 86.813, 89.174, 91.438, 94.180, 94.094,  /*
*/ 95.705, 98.130, 100.000, 101.347, 102.868, 103.126, 104.235, 106.073, 108.231 )'

matrix cpimatus = cpimatus/${cpi2018us}

forvalues yr =  $yrfirst/$yrlast{
	local ee = `yr' - ${yrfirst} + 1
	local ii = `yr' - 1970 + 1
	matrix exrate[`ee',1] = exrate[`ee',1]*(cpimatus[`ii',1]/cpimat[`ee',1])
			// Coverting nominal exchange rate to real exchange rate
}

// CREATING MINIMUM INCOME THRESHOLD USING COUNTRY SPECIFIC MINIMUM WAGE  

matrix minwg_C = /* Nominal minimum wage 1983-2016 in Canada
*/ ( 3.5, 3.65, 3.65, 3.65, 3.65, 4, 4.25, 4.25, 4.5, 4.75, 4.75, 4.75, 4.75, 5, 5, 5.25, /*
*/  5.4, 5.5, 5.5, 5.9, 5.9, 5.9, 6.25, 6.7, 7.25, 7.75, 8, 8, 9.4, 9.75, 9.95,  /*
*/  10.2, 10.3, 10.5 )'


// Change 1959 to the first year in your minwg_C matrix
local yinic = ${yrfirst} - 1983 + 1	
local yend = ${yrlast} - 1983 + 1

matrix mininc_C = 260*minwg_C[`yinic'..`yend',1]		// Nominal min income in the US
														// This uses the factor of 260 given in the Guidelines
matrix rmininc = J(${yrlast}-${yrfirst}+1,1,0)
local i = 1
local tnum = ${yrlast}-${yrfirst}+1
forvalues pp = 1(1)`tnum'{
	matrix rmininc[`i',1] = mininc_C[`i',1]/cpimat[`i',1]					
					// real min income threshold in local currency 
	local i = `i' + 1
}


// CREATING MINIMUM INCOME THRESHOLD USING CUSTOM VALUES 
// (E.G., the bottom 23% of the gender, combined earnings distribution, etc.)  

// PLEASE DO NOT CHANGE THIS PART. IF NEEDS TO BE CHANGED, CONTACT Ozkan/Salgado


// Define the years for which the inequality and concetration measures are calculated

global  yrlist = ""
forvalues yr = $yrfirst(1)$yrlast{
	global yrlist = "${yrlist} `yr'"
}		
	
// Define years for which one-year log-changes measures are calculated
global d1yrlist = ""
local tempyr = $yrlast-1
forvalues yr = $yrfirst(1)`tempyr'{
	global d1yrlist = "${d1yrlist} `yr'"
}
	
// Define years t for which five-years log-changes between t+5 and t are calculated
global d5yrlist = "$yrfirst"
local tempyrb = $yrfirst+1
local tempyr = $yrlast-5
forvalues yr = `tempyrb'(1)`tempyr'{
	local tmp = ",`yr'"
	global d5yrlist = "${d5yrlist}`tmp'"
}	
	
// Define the ending years (t) to construct permanent income between t-2 and t 
local tempyrb = $yrfirst+2	
global perm3yrlist = "`tempyrb'"
local tempyrb = $yrfirst+3	
local tempyre = $yrlast
forvalues yr = `tempyrb'(1)`tempyre'{
	local tmp = ",`yr'"
	global perm3yrlist = "${perm3yrlist}`tmp'"
}	

