// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// These files generate the figures for individual inequality, dynamics, 
// and mobility reported in Sections 2 and 3 of the paper and in Supplemental 
// Appendix SA.
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

set more off
clear all
cls

// Line 12: copy and paste the root directory where all the files are stored. 
gl maindir "~/GRIDCan/individual"

/*------------------------------------------------------------------------------
Lines 23--29: 
 - Paste the names of the subfolders where the main data files and 
   moments are stored. 
 - The various subfolders containing the data files are in 
   $maindir/figurescsv.
 - For example, all data related to inequality that we used in the current paper 
   can be found in $maindir/figurescsv/Inequality. Your folder will have a different name.
------------------------------------------------------------------------------*/
gl ineqdata = "Inequality"	// Data on Inequality
gl voladata = "Volatility"	// Data on Volatility 
gl mobidata = "Mobility"	// Data on Mobility 
gl recesmom = "Recession"  // Data on Cyclical Features

// Line 29: paste name of the folder where you want the figures to be stored.
gl outfolder="Figures"

/*------------------------------------------------------------------------------

File: Initialize_Final.do (line 44)
 - This file initializes all variables required to execute the main file, 
   "Paper_Figs_Final.do."  
 - Nothing in this file requires adjustment.

File: myplots_final.do (line 45)
 - This file contains and initializes all the plotting functions required to 
   produce each figure in the paper.
 - No adjustments are required. 

------------------------------------------------------------------------------*/
do "$maindir/do/0_Initialize.do"
do "$maindir/do/myplots.do"		
		
// Define some common charactristics of the plots 
	gl xtitlesize   = "medlarge" 
	gl ytitlesize   = "medlarge" 
	gl xlabsize     = "medlarge" 
	gl ylabsize     = "medlarge" 
	gl titlesize    = "medlarge" 
	gl subtitlesize = "medlarge" 
	gl formatfile   = "pdf"
	gl fontface     = "Times New Roman"
	gl marksize     = "medium"	
	gl legesize     = "medlarge"	
	
/*------------------------------------------------------------------------------
Lines 64--74: identifies the figures that we are plotting from each section. 
If you do not want to plot figures from a section change “yes” to “no” 
(e.g., figineq  = "no") otherwise don’t change anything.
------------------------------------------------------------------------------*/ 
	gl figineq     = "yes"	// Inequality                       FINAL
	gl figcon      = "yes"  // Earnings shares                  FINAL
	gl figvol      = "yes"  // Volatility                       FINAL
	gl figmob      = "yes"	// Mobility 	   		            FINAL
	gl figquan     = "yes"	// Income growth heterogeneity      FINAL
	gl figcoh      = "yes"	// Cohorts and initial inequality   FINAL
	gl figcoh_comb = "yes"	// Cohorts combined                 FINAL
	gl figtail     = "yes"	// Tail                             FINAL
	gl figden      = "yes"	// Density Plots                    FINAL
	gl figrecmo    = "yes" 	// Cyclical Features 	            FINAL
	gl figt1mpfcov = "yes"  // T1MPF Coverage Rates             FINAL
	
*===============================================================================

/*---------------------------------------------------------	
  Figures: Employment and T1MPF Coverage Rates
  Using: tspltAREALim9 and tspltAREALim10
---------------------------------------------------------*/	

if "${figt1mpfcov}" == "yes"{ 
    
use "$maindir/figurescsv/t1mpf_coverage/emp_t1mpf_coverage_rates_83_2016_byagegroup", clear

#delimit ;
g rece   = year == 1986 |
		   year == 1989 |
		   year == 1990 |
		   year == 1991 |
		   year == 2001 |
		   year == 2003 |
		   year == 2008 |
		   year == 2009 |
		   year == 2015 |
		   year == 2016 ;
#delimit cr


*==========================================*
* EMPLOYMENT RATES BY AGE GROUPS OVER TIME *
*==========================================*

loc xmin   = 1983
loc xmax   = 2016
loc ymin   = 65
loc ymax   = 85
loc dist   = 5
loc endash = ustrunescape("\u2013")

tspltAREALim9 "empr_a2534 empr_a3544 empr_a4554 " /// Which variables?
	   "year" ///
	   `xmin' `xmax' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "25`endash'34" "35`endash'44" "45`endash'54" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "Year" /// x axis title
	    "Employment Rate (%)" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "emprates_by_yearage"	/// Figure name
	   "`ymin'" "`ymax'" "`dist'"				/// ylimits
	   "" 						/// If legend is active or nor	
	    "green black maroon red navy blue forest_green purple gray orange"	/// Colors
		"" "" // 
graph export "$maindir/$outfolder/emprates_by_yearage.pdf", replace

*==============================================*
* T1MPF COVERAGE RATES BY AGE GROUPS OVER TIME *
*==============================================*

loc xmin   = 1983
loc xmax   = 2016
loc ymin   = 85
loc ymax   = 100
loc dist   = 5
loc endash = ustrunescape("\u2013")

tspltAREALim9 "t1mpfcov_a2534 t1mpfcov_a3544 t1mpfcov_a4554" /// Which variables?
	   "year" ///
	   `xmin' `xmax' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "25`endash'34" "35`endash'44" "45`endash'54" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "Year" /// x axis title
	    "T1MPF Coverage Rate (%)" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "t1mpfcovr_by_yearage"	/// Figure name
	   "`ymin'" "`ymax'" "`dist'"				/// ylimits
	   "" 						/// If legend is active or nor	
	    "green black maroon red navy blue forest_green purple gray orange"	/// Colors
		"" "" // 
graph export "$maindir/$outfolder/t1mpfcovrates_by_yearage.pdf", replace

* T1MPF COVERAGE WITH ALTERANTIVE POPULATION ESTIMATES *

tspltAREALim9 "t1mpfcovalt_a2534 t1mpfcovalt_a3544 t1mpfcovalt_a4554" /// Which variables?
	   "year" ///
	   `xmin' `xmax' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "25`endash'34" "35`endash'44" "45`endash'54" "" "" "" "" "" "" /// Labels 
	   "1" "1" ///
	   "Year" /// x axis title
	    "T1MPF Coverage Rate (%)" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "t1mpfcovr_by_yearage"	/// Figure name
	   "`ymin'" "`ymax'" "`dist'"				/// ylimits
	   "" 						/// If legend is active or nor	
	    "green black maroon red navy blue forest_green purple gray orange"	/// Colors
		"" "" // 
graph export "$maindir/$outfolder/t1mpfcovratesalt_by_yearage.pdf", replace


* T1MPF COVERAGE WITH FULL SAMPLE *

tspltAREALim10 "t1mpfcov_a2554 t1mpfcov_a2534 t1mpfcov_a3544 t1mpfcov_a4554" /// Which variables?
	   "year" ///
	   `xmin' `xmax' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "All (25`endash'54)" "25`endash'34" "35`endash'44" "45`endash'54"  "" "" "" "" "" /// Labels 
	   "2" "11" ///
	   "Year" /// x axis title
	    "T1MPF Coverage Rate (%)" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "t1mpfcovr_by_yearage"	/// Figure name
	   "`ymin'" "`ymax'" "`dist'"				/// ylimits
	   "" 						/// If legend is active or nor	
	    "navy green orange maroon black red blue forest_green purple gray "	/// Colors
		"" "" // 
graph export "$maindir/$outfolder/t1mpfcovrates_by_yearagewfull.pdf", replace	

use "$maindir/figurescsv/t1mpf_coverage/emp_t1mpf_coverage_rates_83_2016_byagegroup_update.dta", clear

#delimit ;
g rece   = year == 1986 |
		   year == 1989 |
		   year == 1990 |
		   year == 1991 |
		   year == 2001 |
		   year == 2003 |
		   year == 2008 |
		   year == 2009 |
		   year == 2015 |
		   year == 2016 ;
#delimit cr

loc xmin   = 1983
loc xmax   = 2016
loc ymin   = 88
loc ymax   = 94
loc dist   = 2
loc endash = ustrunescape("\u2013")

* T1MPF FULL SAMPLE ONLY *
	
tspltAREALim10 "t1mpfcov_a2555" /// Which variables?
	   "year" ///
	   `xmin' `xmax' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Full (25`endash'55)" "" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "Year" /// x axis title
	    "T1MPF Coverage Rate (%)" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "t1mpfcovr_by_yearage"	/// Figure name
	   "`ymin'" "`ymax'" "`dist'"				/// ylimits
	   "off" 						/// If legend is active or nor	
	    "black maroon red green black navy blue forest_green purple gray orange"	/// Colors
		"" "" // 
graph export "$maindir/$outfolder/t1mpfcovrates_by_yearfullage.pdf", replace	


use "$maindir/figurescsv/minwage_emprate_data_files/data_suppfigs.dta", clear

#delimit ;
gen rece = year == 1986 |
		   year == 1989 |
		   year == 1990 |
		   year == 1991 |
		   year == 2001 |
		   year == 2003 |
		   year == 2008 |
		   year == 2009 |
		   year == 2015 |
		   year == 2016 ;
gen rece1 = rece*60 + 100;
gen rece2 = rece*32 + 58;
gen rece3 = rece*8  + 6;
#delimit cr


*==============*
* FIGURE 1 (a) *
*==============*

#delimit ;
tw 
( bar rece1 year, c(l) color(gray*0.5))
(scatter rgdppc year, 
connect(l) msymbol(d) msize(s) lwidth(s)
graphregion(color(white)) bgcolor(white)
xtitle("")
ytitle("Real GDP Per Capita Index",size(large))
xlab(1983(3)2016,grid)
ylab(100(20)160,grid)
legend(off)
note("Source: Statistics Canada, Table: 36-10-0212-01", size(medium)) );
#delimit cr

graph export "$maindir/$outfolder/rgdp_percap.pdf", replace


*==============*
* FIGURE 1 (b) *
*==============*

#delimit ;
tw 
( bar rece2 year, c(l) color(gray*0.5))
(scatter emp_men2554 emp_fem2554 year, 
connect(l l) msymbol(d t) msize(s s) lwidth(s s) lcolor(maroon navy) mc(maroon navy)
graphregion(color(white)) bgcolor(white)
xtitle("") 
ytitle("%", size(large))
xlab(1983(3)2016,grid)
legend( order( 2 "Men (25-54)" 
			   3 "Women (25-54)") )
legend(col(1) nobox)
legend(region(color(none)) ring(0) pos(5))
note("Source: Statistics Canada, Table: 14-10-0018-01",size(medium)) );
#delimit cr

graph export "$maindir/$outfolder/emprate_bysex_2554.pdf", replace


*===========*
* FIGURE 25 *
*===========*

#delimit ;
tw
( bar rece3 year, c(l) color(gray*0.35))
(scatter minwage_real ON BC QC AB PE SK MA NB NL NS year, 
connect(l l l l l l l l l l l) 
msymbol(t) 
mc(dknavy none none none none none none none none none none)
lcolor(dknavy maroon dkorange emerald forest_green)
lpattern( solid 
		  longdash_dot 
		  dash_dot shortdash 
		  shortdash_dot 
		  longdash_dot 
		  longdash_dot 
		  dash_dot 
		  shortdash 
		  shortdash_dot 
		  longdash_dot )
msymbol(d) 
lwidth(small small small small small small small small small small small)
graphregion(color(white)) bgcolor(white)
xtitle("Year") 
ytitle("Real Minimum Hourly Wage ($2018)")
xlab(1983(3)2016)
text(10.4 1992 "ON", color(maroon) size(medium))
text(11.2 2001 "BC", color(dkorange) size(medium))
text(9.9 2002 "QC", color(emerald) size(medium))
text(13 2016 "AB", color(forest_green) size(medium))
legend(off)
note("Source: Employment and Social Development Canada (2014)") ) ;
#delimit cr

graph export  "$maindir/$outfolder/minwage_byprov.pdf", replace
    
}

/*---------------------------------------------------------	
  Figures: Inequality 
  Using: tspltAREALimPA	
---------------------------------------------------------*/

if "${figineq}" == "yes"{ 	

// PLOTS OF LOG EARN: The limints need to change for each variable; Better seperate them
	*Define the saving folder 
	gl folderfile = "$maindir/${outfolder}"
	
	*foreach subgp in fem male all{	
    foreach subgp in all male fem {	
	
	*For residual-education earnings we are only ploting the aggregated results
	if 	"`subgp'" == "all"{
		local wlist = "logearn researn permearn"	
		//local wlist = "logearn"	
	}	
	else {
		local wlist = "logearn researn permearn"	
		//local wlist = "logearn"	
	}
	
	*Start main loop over variables
	foreach var of local wlist{
	
	*Which variable will be ploted
	gl vari = "`var'"						 
	
	*What is the group under analysis? 

	if "`subgp'" == "all"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_sumstat.csv", clear
		local labname = "All"
	}
	if "`subgp'" == "male" & "${vari}"== "logearn" {
        insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_male_sumstat_imp.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local labname = "Men"
	}

	if "`subgp'" == "male" & ("${vari}"== "researn" | "${vari}"== "permearn") {
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_male_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local labname = "Men"
		*** There are some missing values for women 
		replace p99_99${vari}="." if p99_99${vari}=="x"
	    destring(p99_99${vari}), replace
	}
		
	if "`subgp'" == "fem" & "${vari}" == "logearn" {
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_male_sumstat_imp.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local labname = "Women"
	}

	if "`subgp'" == "fem" & ("${vari}"== "researn" | "${vari}"== "permearn") {
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_male_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local labname = "Women"
		*** There are some missing values for women 
		replace p99_99${vari}="." if p99_99${vari}=="x"
    	destring(p99_99${vari}), replace
	}

	*What is the label for title 
	if "${vari}" == "logearn"{
 		local labtitle = "log y{sub:it}"
	}
	if "${vari}" == "researn" {
 		local labtitle = "{&epsilon}{sub:it}"
	}
	if "${vari}" ==  "permearn"{
		local labtitle = "{&epsilon}{sup:P}{sub:it}"
	}

	*What are the x-axis limits
	if "${vari}" == "logearn"{
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	if "${vari}" == "researn" {
		local lyear = ${yrfirst}
		local ryear = ${yrlast}
	}
	
	if "${vari}" == "permearn"{
		local lyear = ${yrfirst}+2
		local ryear = ${yrlast}
	}
	
	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9901${vari} = p99${vari} - p1${vari}
	gen p99901${vari} = p99_9${vari} - p1${vari}
	gen p999901${vari} = p99_99${vari} - p1${vari}
	
	gen p9990${vari} = p99${vari} - p90${vari}
	gen p999_p99${vari} = p99_9${vari} - p99${vari}
	gen p9999_p999${vari} = p99_99${vari} - p99_9${vari}
	
	
	gen p9505${vari} = p95${vari} - p5${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}

	*Rescale by first year 
	foreach vv in sd$vari  var$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari p99_99$vari p9010$vari  p9901$vari  p9505$vari p9050${vari} p5010${vari} ksk${vari} ///
		p99901${vari} p999901${vari} p9990${vari} p999_p99${vari} p9999_p999${vari} {
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		}
	
	*Generate recession vars
	gen rece = inlist(year,${receyears})
	
	*Rescale standard deviation for plots
	replace sd$vari = 2.56*sd$vari

// Figure 1A (normalized percentiles)
	local y1 = ""
	local y2 = ""
	local y2 = ""
	
	if "${vari}" == "logearn"{
		local y1 = -0.2
		local y2 = 0.5
		local y3 = 0.1
	}
	if "${vari}" == "researn" {
		local y1 = -.15
		local y2 =  .15
		local y3 = .05
	}
	
	if "${vari}" == "permearn" {
		local y1 = -.15
		local y2 =  .2
		local y3 = .05
	}

	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1A_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"		/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D" 
	   
// Figures 1B (normalized top percentiles)	 
	if "${vari}" == "logearn"{
		local y1 = -0.1
		local y2 = 1.5
		local y3 = 0.2
	}
	if "${vari}" == "researn"{
		local y1 = -0.1
		local y2 = 1.3
		local y3 = 0.2
	}
	if "${vari}" == "permearn" {
		local y1 = 0
		local y2 = 1.2
		local y3 = 0.2
	}
	
	tspltAREALimPA "np99_99$vari np99_9$vari np99$vari np95$vari np90$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p99.99" "p99.9" "p99" "p95" "p90" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `lyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig1B_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "D + S x O" 

// Figure 2 (Inequality)	
	if "${vari}" == "logearn"{
		local y1 = 1.8
		local y2 = 2.33
		local y3 = 0.1
	}
	if "${vari}" == "researn"{
		local y1 = 1.7
		local y2 = 2.3
		local y3 = 0.1
	}
	if "${vari}" == "permearn" {
		local y1 = 1.4
		local y2 = 1.9
		local y3 = 0.1
	}
		   		   
	tspltAREALimPA "sd$vari p9010$vari" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "2.56*{&sigma}" "P90-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2A_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 
	   
	if "${vari}" == "logearn"{
		local y1 = 0.5
		local y2 = 1.5
		local y3 = 0.2
	} 
	if "${vari}" == "researn"{
		local y1 = 0.5
		local y2 = 1.5
		local y3 = 0.2
	}
	if "${vari}" == "permearn" {
		local y1 = 0.5
		local y2 = 1.2
		local y3 = 0.2
	}
	 tspltAREALimPA "p9050$vari  p5010$vari " /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
	   "1" "1" ///
	   "" /// x axis title
	   "Dispersion of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig2B_`subgp'_${vari}"	/// Figure name
	   "`y1'" "`y2'" "`y3'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 	  		


	   }	// END of loop over subgroups
	   

}		// END loop over variables

}	// END of inequality section
		
/*----------------------------------------------------	
  Figures: Earnings shares
  Using: tspltAREALim, tspltAREALim2
----------------------------------------------------*/

if "${figcon}" == "yes"{ 
	*Folder to save figures 
	gl folderfile = "$maindir/${outfolder}"
	
	*foreach subgp in all male fem{
    
	*** HERE only for all 
	foreach subgp in all {
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using  "$maindir/figurescsv/${ineqdata}/L_earn_con.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_earn_con_male.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
	}	
	if "`subgp'" == "fem"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_earn_con_male.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
	}
	
	
	*Normalizing data to value in ${normyear}
	local lyear = ${normyear}	// Normalization year
	foreach vv in q1share q2share q3share q4share q5share ///
				  top10share top5share top1share top05share top01share top001share ///
				  bot50share{
		
		sum  `vv' if year == `lyear', meanonly
		gen n`vv' = `vv' - r(mean)
		
		}
		
		
	gen t01_001 = top01share - top001share
	gen t05_01 = top05share - top01share
	gen t1_05 = top1share - top05share
	gen t5_1 = top5share - top1share
	gen t10_5 = top10share - top5share
	
	foreach kk in t01_001 t05_01 t1_05 t5_1 t10_5{

	    sum  `kk' if year == `lyear', meanonly
		gen n`kk' = `kk' - r(mean)
		
	}
		
	*What years 
	local rlast = ${yrlast}
	
	*Recession bars 
	gen rece = inlist(year,${receyears})
	
				   	  
	tspltAREALim "nq1share nq2share nq3share nq4share nq5share" /// Which variables?
		   "year" ///
		   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "Q1" "Q2" "Q3" "Q4" "Q5" "" "" "" "" /// Labels 
		    "1" "11" ///
		   "" /// x axis title
		   "Earnings Shares (%  `lyear' = 0)" /// y axis title 
		   "" ///  Plot title
		   ""  /// 	 Plot subtitle  (left blank in this example)
		   "fig3b_nquintile_`subgp'"	/// Figure name
		   "-2.5" "6" "1"				/// ylimits
		   "" 						/// If legend is active or nor	
	       "green black maroon red navy blue forest_green purple gray orange"			// Colors

		   
	tspltAREALim "ntop10share ntop5share ntop1share ntop05share ntop01share ntop001share" /// Which variables?
		   "year" ///
		   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "Top 10%" "Top 5%" "Top 1%" "Top 0.5%" "Top 0.1%" "Top 0.01%" "" "" "" /// Labels 
		   "1" "11" ///
		   "" /// x axis title
		    "Earnings Shares (%  `lyear' = 0)" /// y axis title 
		   "" ///  Plot title
		   ""  /// 	 Plot subtitle  (left blank in this example)
		   "fig3b_ntopshares_`subgp'"	/// Figure name
		   "-2.5" "6" "1"				/// ylimits
		   "" 						/// If legend is active or nor	
	       "green black maroon red navy blue forest_green purple gray orange"			// Colors

		 	   
	*Gini
	tspltAREALim2 "gini" /// Which variables?
		   "year" ///
		   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "Gini" "" "" "" "" "" "" "" "" /// Labels 
		   "1" "11" ///
		   "" /// x axis title
		   "Gini Coefficient" /// y axis title 
		   "" ///  Plot title
		   ""  /// 	 Plot subtitle  (left blank in this example)
		   "fig3b_gini_`subgp'"	/// Figure name
		    "" "" ""				/// ylimits
		   "off" 						/// If legend is active or nor	
		   "blue red"			// Colors
		   
     
	tspltAREALim "nt10_5 nt5_1 nt1_05 nt05_01 nt01_001 ntop001share" /// Which variables?
		   "year" ///
		   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "Top 5% to 10%" "Top 1% to 5%" "Top 0.5% to 1%" "Top 0.1% to 0.5%" "Top 0.01% to 0.1%" "Top 0.01%" "" "" "" /// Labels 
		   "1" "11" ///
		   "" /// x axis title
		    "Earnings Shares (%  `lyear' = 0)" /// y axis title 
		   "" ///  Plot title
		   ""  /// 	 Plot subtitle  (left blank in this example)
		   "fig3b_ntopshares_diff_`subgp'"	/// Figure name
		   "-0.5" "2" ".5"				/// ylimits
		   "" 						/// If legend is active or nor	
	       "green black maroon red navy blue forest_green purple gray orange"			// Colors
    
		   
		   
}	// END of loop over variables
} // END of section 

/*----------------------------------------------------	
  Figures: Cyclical features
  Using: no program
----------------------------------------------------*/

if "${figrecmo}" == "yes"{ 
	
	*Folder to save figures 
	gl folderfile = "$maindir/${outfolder}"

*==========*
* FIGURE 7 *
*==========*

use "$maindir/figurescsv/$recesmom/recession_moments_all_merged_1990_1995.dta", clear
order quartile nyear 
drop p5_90-p95_90 p5_95-p95_95 year_90 year_95 rece_90 rece_95
keep if nyear <= 10

foreach n of num 5 10 25 50 75 90 95 {
	
	rename np`n'_90 p`n'_90
	rename np`n'_95 p`n'_95
	
}

loc formatfile = "${formatfile}"			// format of saved file 
loc folderfile = "${folderfile}"			// folder where the plot is saved

forvalues q = 1/4 {
	
#delimit ;

scatter p10_90 p50_90 p90_90 p10_95 p50_95 p90_95 nyear if quartile == `q',
connect(l l l l l l) lp(l l l dash dash dash) m(o d t o d t)
lc(maroon green dkorange maroon green dkorange)
mc(maroon green dkorange maroon green dkorange)
mfc(maroon*0.5 green*0.5 dkorange*0.5 maroon*0.5 green*0.5 dkorange*0.5)
ylab(-0.5(0.2)0.6,grid labsize(${ylabsize})) xlab(,grid labsize(${xlabsize}) )
xtitle("Years Since 1988 or 1995", size(${xtitlesize}))
ytitle(,size(${ytitlesize}))
legend(symxsize(7.0)  col(3) ring(0) position(11) size(${legesize}))
legend( 

order(1 "p10 (1988-1998)" 
	  2 "p50 (1988-1998)" 
	  3 "p90 (1988-1998)" 
	  4 "p10 (1995-2005)"
	  5 "p50 (1995-2005)" 
	  6 "p90 (1995-2005)")
	region(color(none) lcolor(white))) graphregion(color(white) 
	
	) 
graphregion(color(white)) 
plotregion(lcolor(black)) ;
cap noisily: graph export "`folderfile'/perc_logy_changes_1990_1995_q`q'.`formatfile'", replace ;

#delimit cr
	
}

*============*
* FIGURE A13 *
*============*

use "$maindir/figurescsv/$recesmom/recession_moments_all_merged_1995_2008.dta", clear
order quartile nyear 
drop p5_08-p95_08 p5_95-p95_95 year_95 year_08 rece_08 rece_95
keep if nyear < 10

foreach n of num 5 10 25 50 75 90 95 {
	
	rename np`n'_08 p`n'_08
	rename np`n'_95 p`n'_95
	
}

forvalues q = 1/4 {
	
#delimit ;

scatter p10_95 p50_95 p90_95 p10_08 p50_08 p90_08 nyear if quartile == `q',
connect(l l l l l l) lp(l l l dash dash dash) m(o d t o d t)
lc(maroon green dkorange maroon green dkorange)
mc(maroon green dkorange maroon green dkorange)
mfc(maroon*0.5 green*0.5 dkorange*0.5 maroon*0.5 green*0.5 dkorange*0.5)
ylab(-0.4(0.2)0.6,grid labsize(${ylabsize})) xlab(0(1)9,grid labsize(${xlabsize}))
xtitle("Years Since 1995 or 2007", size(${xtitlesize}))
ytitle(,size(${ytitlesize}))
legend(symxsize(7.0)  col(3) ring(0) position(11) size(${legesize}))
legend( 

order( 1 "p10 (1995-2004)" 
	   2 "p50 (1995-2004)" 
	   3 "p90 (1995-2004)" 
	   4 "p10 (2007-2016)"
	   5 "p50 (2007-2016)" 
	   6 "p90 (2007-2016)" )
	region(color(none) lcolor(white))) graphregion(color(white) 
	
	) 
graphregion(color(white)) 
plotregion(lcolor(black)) ;
cap noisily: graph export "`folderfile'/perc_logy_changes_1995_2008_q`q'.`formatfile'", replace ;

#delimit cr

}
	
}

/*---------------------------------------------------	
  Figures: Volatility
  Using: tspltAREALimPA
 ---------------------------------------------------*/
if "${figvol}" == "yes"{  



foreach var in  researn1F researn5F {	
	foreach subgp in male fem {
	
	*Which variable will be ploted
	global vari = "`var'"						 
	
	*What is the group under analysis? 
	if "`subgp'" == "all"{
		insheet using "$maindir/figurescsv/${voladata}/L_`var'_sumstat.csv", case clear
		local labtitle2 = "All"
	}
	if "`subgp'" == "male"{
		insheet using "$maindir/figurescsv/${voladata}/L_`var'_male_sumstat.csv", case clear
		keep if male == 1	// Keep the group we want to plot 
		local labtitle2 = "Men"
	}
		
	if "`subgp'" == "fem"{
		insheet using "$maindir/figurescsv/${voladata}/L_`var'_male_sumstat.csv", case clear
		keep if male == 0	// Keep the group we want to plot 
		local labtitle2 = "Women"
	}

	
	*What is the label for title 
	if "${vari}" == "researn1F"{
		local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"
	}
	if "${vari}" == "arcearn1F"{
		local labtitle = "{&Delta}{sup:1}dhs{sub:it}"
	}
	if "${vari}" == "researn5F"{
		local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"
	}
	if "${vari}" == "arcearn5F"{
		local labtitle = "{&Delta}{sup:5}dhs{sub:it}"
	}
	
	
	*What are the x-axis limits
	if "${vari}" == "researn1F"  | "${vari}" == "arcearn1F"  {
		local lyear = ${yrlast}-1		
		local ljum = 0
		local fyear = ${yrfirst} + `ljum'
		local nyear = ${normyear}
	}
	if "${vari}" == "researn5F" | "${vari}" == "arcearn5F"{
		local lyear = ${yrlast} - 2
		local ljum = 0		// So plot is centered in year 3
		local fyear = ${yrfirst} + 3
		local nyear = `fyear'
		replace year = year + 3		// This just re labels the year to center the 5-year changes to the "middle" year. 	
									// I.e. if your data goes from 1993/2017 and the first 5-years change in between 1993 and 1998
									// the "middle" year is 1996 (which is the starting point of your plot)
									// The last 5 year change dates on 2012, which will be plotted in the "middle" year, 2015
	}


	*Normalize Percentiles 
	gen var${vari} = sd${vari}^2
	gen sdr${vari} = 2.56*sd${vari}             //Rescaled standard deviation for plots
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen p7525${vari} = p75${vari} - p25${vari}
	
	gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari}
	
	
	*Rescale by first year 
	foreach vv in sd$vari sdr$vari var${vari} p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
		p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
		p97_5$vari p99$vari p99_9$vari  ///
		p9010${vari} p9050${vari} p5010${vari} p7525${vari} ksk${vari} {
		sum  `vv' if year == `nyear', meanonly
		qui: gen n`vv' = `vv' - r(mean)
		
	}
		
	*What are the recession years
	gen rece = inlist(year,${receyears})
	
	tsset year
	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.12
			local ylimup = 0.12
			local ylimdf = 0.04	
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.3
			local ylimup = 0.24
			local ylimdf = 0.1	
			
		}

		
    // Figure 4	 
	tspltAREALimPA "L`ljum'.np90$vari L`ljum'.np75$vari L`ljum'.np50$vari L`ljum'.np25$vari L`ljum'.np10$vari" /// Which variables?
	   "year" ///
	   `fyear' `lyear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Percentiles Relative to `fyear'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig4ashort_`subgp'_n${vari}"	/// Figure name
	   "`ylimlo'" "`ylimup'" "`ylimdf'"	/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D"  //
	   
		   
	   }	// END of loop over subgroups
}



*Time series for slides 

	*Plot One-year changes
	foreach jj in 1 5{ 
		
	global folderfile = "$maindir/${outfolder}"
	global vari = "researn`jj'F"

	
	*Figure 4
	foreach subgp in men women {
	
	
		if "${vari}" == "researn1F"{
			local lyear = ${yrfirst}
			local ryear = ${yrlast}
			*local labtitle = "g{sup:1}{sub:it}"
			local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"
		}		
		if "${vari}" == "researn5F"{
			local lyear = ${yrfirst} + 3
			local ryear = ${yrlast} - 2	
			*local labtitle = "g{sup:5}{sub:it}" // ?? what labels here?
			local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"
		}
	
	
	
		*Load data 				
		insheet using "$maindir/figurescsv/${voladata}/L_${vari}_male_sumstat.csv", case clear
		
		if "`subgp'" == "men"{
			keep if male == 1
		}
		else{
			keep if male == 0
		}				
		
		
		gen p9050$vari = p90$vari - p50$vari
		gen p5010$vari = p50$vari - p10$vari
		gen p9010$vari = p90$vari - p10$vari
		gen var$vari = sd$vari^2
		gen sdr${vari} = 2.56*sd${vari}             //Rescaled standard deviation for plots
		
		if "${vari}" == "researn1F"{
			
			* For the two axis plot
			local ylimlo1 = 0.65
			local ylimup1 = 1.1
			local ylimdf1 = 0.1	
			
			local ylimlo2 = 0.22
			local ylimup2 = 0.36
			local ylimdf2 = 0.02	

	    	local ylimlo = 0.2
	 		local ylimup = 0.65
			local ylimdf = 0.1	
			
			local ylimlo_2 = 0.65
			local ylimup_2 = 1.62
			local ylimdf_2 = .15
						
			gen rece = inlist(year,${receyears})
		}
		
		if "${vari}" == "researn5F"{

			* For the two axis plot
			local ylimlo1 = 1.2
			local ylimup1 = 1.8
			local ylimdf1 = 0.2	
			
			local ylimlo2 = 0.45
			local ylimup2 = 0.7
			local ylimdf2 = 0.05	
			
	    	local ylimlo = 0.5
			local ylimup = 0.95
			local ylimdf = 0.1	
			replace year = year + 3		// This is to center the 5-year changes
			
			local ylimlo_2 = 1.2
			local ylimup_2 = 2.2
			local ylimdf_2 = .2
			
			
			gen rece = inlist(year,${receyears})
		}
		
		   
		  tspltAREALimPA "sdr$vari p9010$vari" /// Which variables?
			"year" ///
			`lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
			"2.56*{&sigma}" "P90-P10" "" "" "" "" "" "" "" /// Labels 
			"1" "2" ///
			"" /// x axis title
			"Dispersion of `labtitle'" /// y axis title 
			"" ///  Plot title
			"" ///
			"fig5a_`subgp'_${vari}COMPARE_2"	/// Figure name
			"`ylimlo_2'" "`ylimup_2'" "`ylimdf_2'"				/// ylimits
			"" 						/// If legend is active or nor	
			"blue red navy blue maroon forest_green purple gray orange"			/// Colors
			"O S" //
			


			
			
		tspltAREALimPA "p9050$vari  p5010$vari" /// Which variables?
		   "year" ///
		   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "P90-P50" "P50-P10" "" "" "" "" "" "" "" /// Labels 
		   "1" "1" ///
		   "" /// x axis title
		   "Dispersion of `labtitle'" /// y axis title 
		   "" ///  Plot title
		   "" ///
		   "fig4_`subgp'_${vari}"	/// Figure name
		   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
		   "" 						/// If legend is active or nor	
		   "blue red navy blue maroon forest_green purple gray orange"			/// Colors
		   "O S" 

		   
	}




	*Figure 5
	insheet using "$maindir/figurescsv/${voladata}/L_${vari}_male_sumstat.csv", case clear
	gen ksk${vari} = ((p90${vari} - p50${vari}) - (p50${vari} - p10${vari}) )/(p90$vari - p10${vari})
	gen cku${vari} = (p97_5${vari} - p2_5${vari})/(p75$vari - p25${vari}) - 2.91
	
	replace kurt${vari} = kurt${vari} - 3 //Excess
	
	keep year male ksk${vari} cku${vari} skew${vari} kurt${vari}
	reshape wide ksk${vari} cku${vari} skew${vari} kurt${vari}, i(year) j(male)
	
	if "${vari}" == "researn1F"{
		local ylimlo = -0.3
		local ylimup = 0.2
		local ylimdf = 0.1	
		
		local ylimlo2 = -1.5
		local ylimup2 = -0.7
		local ylimdf2 = 0.2		
		
		gen rece = inlist(year,${receyears})

	}		
	if "${vari}" == "researn5F"{
		local ylimlo = -0.25
		local ylimup = 0.2
		local ylimdf = 0.05		

		local ylimlo2 = -1.2
		local ylimup2 = -0.4
		local ylimdf2 = 0.2		

		
		replace year = year + 3		// This is to center the 5-year changes
		
		gen rece = inlist(year,${receyears})
	}

	
	 tspltAREALimPA "ksk${vari}0 ksk${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "5" ///
	   "" /// x axis title
	   "Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_${vari}"	/// Figure name
		"`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "yes"	
	   
	 tspltAREALimPA "skew${vari}0 skew${vari}1" /// Which variables? 
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "5" ///
	   "" /// x axis title
	   "Coef. of Skewness of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5A_${vari}_coef"	/// Figure name
		"`ylimlo2'" "`ylimup2'" "`ylimdf2'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" "no"		   

	   
	if "${vari}" == "researn1F"{
		local ylimlo = 7
		local ylimup = 12
		local ylimdf = 1
		
		local ylimlo2 = 7
		local ylimup2 = 13.2
		local ylimdf2 = 1	

	}		
	if "${vari}" == "researn5F"{
		local ylimlo = 3
		local ylimup = 6.5
		local ylimdf = 1	
		
		local ylimlo2 = 3.5
		local ylimup2 = 8.5
		local ylimdf2 = 1			

	}
 	 
	 tspltAREALimPA "cku${vari}0 cku${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Excess Kurtosis of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5B_${vari}"	/// Figure name
	   "`ylimlo'" "`ylimup'" "`ylimdf'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 
	   
	 tspltAREALimPA "kurt${vari}0 kurt${vari}1" /// Which variables?
	   "year" ///
	   `lyear' `ryear' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "Women" "Men" "" "" "" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "" /// x axis title
	   "Coef. of Excess Kurtosis of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig5B_${vari}_coef"	/// Figure name
	   "`ylimlo2'" "`ylimup2'" "`ylimdf2'"				/// ylimits
	   "" 						/// If legend is active or nor	
	   "red blue navy blue maroon forest_green purple gray orange"			/// Colors
	   "O S" 
	   

	   
	   }	// END loop jumps
   
	   
}

/*---------------------------------------------------	
 Figures: Income growth heterogeneity
 ---------------------------------------------------*/	

if "${figquan}" == "yes"{ 
	
		foreach mm in  0 1{		// 0: Women; 1: Men; 2: All		
		foreach jj in  1 5{
		local var = "researn`jj'F"
		gl vari = "`var'"

		*What is the label for title 
		if "${vari}"== "researn1F"{
			local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"
			gl folderfile = "$maindir/${outfolder}" 	
		}
		if "${vari}" == "researn5F"{
			local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"
			gl folderfile = "$maindir/${outfolder}" 	
		}
	 
		*Load the data for the last percentile
		insheet using "$maindir/figurescsv/${voladata}/L_`var'_maleagerank.csv", clear case
		
		*Calculate additional moments 
		gen p9010${vari} = p90${vari} - p10${vari}
		gen p9050${vari} = p90${vari} - p50${vari}
		gen p5010${vari} = p50${vari} - p10${vari}
		gen p7525${vari} = p75${vari} - p25${vari}
		gen ksk${vari} = (p9050${vari} - p5010${vari})/p9010${vari}
		gen cku${vari} = (p97_5${vari} - p2_5${vari})/p7525${vari} - 2.91		// Excess Kurtosis
		replace kurt${vari} = kurt${vari} - 3.0		// Excess Kurtosis
		
		if `mm' == 1{
			keep if male == `mm'
			local lname = "men"
			local mlabel = "Men"
		}
		else if `mm' == 0{
			keep if male == `mm'
			local lname = "women"
			local mlabel = "Women"
		}
		
						
		collapse  p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, by(agegp permrank)
		reshape wide p9010${vari} p9050${vari} p5010${vari} sd${vari} ksk${vari} skew${vari} cku${vari} kurt${vari}, i(permrank) j(agegp)
		
		*Idex for plot: the code calculates the top 0.1% in a seperated group (group 42). Since some countries might have 
		*top coded values, we do not plot the top 0.1%
		gen idex = _n
		order idex 
	
		*Figure A		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.0
			local ylimup = 2
			local ylimdf = 0.5			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.5
			local ylimup = 3.5
			local ylimdf = 0.5		
		}
		
		
		tw (connected p9010${vari}1 p9010${vari}2 p9010${vari}3 permrank if idex<=42, msymbol(none none none)  ///
		color(red blue green) lpattern(solid longdash dash) lwidth(medthick medthick medthick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of {&epsilon}{sup:P}{sub:it-1}", size(${xtitlesize})) ///
		ytitle("P90-P10", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))		
		graph export "${folderfile}/fig8a_${vari}_`lname'.pdf", replace 
		
			
		*Figure B	
		if "${vari}" == "researn1F"{
			local ylimlo = -0.3
			local ylimup = 0.15
			local ylimdf = 0.1			
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -0.4
			local ylimup = 0.1
			local ylimdf = 0.1		
		}
		
		
		tw (connected ksk${vari}1 ksk${vari}2 ksk${vari}3 permrank if idex<=42, msymbol(none none none) ///
		color(red blue green) lpattern(solid longdash dash) lwidth(medthick medthick medthick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of {&epsilon}{sup:P}{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Kelley Skewness", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig9a_${vari}_`lname'.pdf", replace 

				
		*Figure C
		if "${vari}" == "researn1F"{
			local ylimlo = 1
			local ylimup = 13
			local ylimdf = 2
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0
			local ylimup = 9
			local ylimdf = 2	
		}
		
		tw (connected cku${vari}1 cku${vari}2 cku${vari}3 permrank if idex<=42, msymbol(none none none) ///
		color(red blue green) lpattern(solid longdash dash) lwidth(medthick medthick medthick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of {&epsilon}{sup:P}{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Excess Crow-Siddiqui Kurtosis", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))
		graph export "${folderfile}/fig10a_${vari}_`lname'.pdf", replace 	

		
		
		*For appendix
		*Figure AA
		
		if "${vari}" == "researn1F"{
			local ylimlo = 0.25
			local ylimup = 1
			local ylimdf = .25
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0.4
			local ylimup = 1.49
			local ylimdf = .3	
		}
		
		
		tw (connected sd${vari}1 sd${vari}2 sd${vari}3 permrank if idex<=42, msymbol(none none none)  ///
		color(red blue green) lpattern(solid longdash dash) lwidth(medthick medthick medthick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(2) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of {&epsilon}{sup:P}{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Standard Deviation", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))
		graph export "${folderfile}/fig8b_${vari}_`lname'.pdf", replace 		

		
			
		*Figure BB			
		if "${vari}" == "researn1F"{
			local ylimlo = -4
			local ylimup = 0
			local ylimdf = 1
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = -4
			local ylimup = 0
			local ylimdf = 1
		}
		
		
		tw (connected skew${vari}1 skew${vari}2 skew${vari}3 permrank if idex<=42, msymbol(none none none) ///
		color(red blue green) lpattern(solid longdash dash) lwidth(medthick medthick medthick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(7) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of {&epsilon}{sup:P}{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Coef. of Skewness", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize}))  yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig9b_${vari}_`lname'.pdf", replace 
		
		*Figure CC
		if "${vari}" == "researn1F"{
			local ylimlo = 0
			local ylimup = 70
			local ylimdf = 10
		}		
		if "${vari}" == "researn5F"{
			local ylimlo = 0
			local ylimup = 30
			local ylimdf = 5
		}
		
		
		tw (connected kurt${vari}1 kurt${vari}2 kurt${vari}3 permrank if idex<=42, msymbol(none none none) ///
		color(red blue green) lpattern(solid longdash dash) lwidth(medthick medthick medthick)), ///
		xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 100 "100", labsize(${xlabsize}) grid) ///
		graphregion(color(white)) plotregion(lcolor(black)) ///
		legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
		xtitle("Quantiles of {&epsilon}{sup:P}{sub:it-1}", size(${xtitlesize}))  ///
		ytitle("Coef. of Excess Kurtosis", size(${ytitlesize})) ///
		title("", color(black) size(${titlesize})) ylabel(`ylimlo'(`ylimdf')`ylimup',labsize(${ylabsize})) yline(0,lcolor(black) lpattern(dash))
		graph export "${folderfile}/fig10b_${vari}_`lname'.pdf", replace 	

		
		}	// END loop variables		
		}	// END loop men/women	
}	
	
/*---------------------------------------------------	
 Figures: Mobility
 ---------------------------------------------------*/	
 
if "${figmob}" == "yes"{ 
	
	*What is the folder to save files 

	gl folderfile = "$maindir/${outfolder}"
	
		foreach mm in  0 1{			/*Gender: Men 1; Women 0*/		
		/*Load Data*/
		insheet using "$maindir/figurescsv/${mobidata}/L_male_agegp_permearnalt_mobstat.csv", clear
		
		keep if male == `mm'
		collapse meanpermearnaltranktp5 [aw=npermearnaltranktp5], by(permearnaltrankt year)
		keep meanpermearnaltranktp5 permearnaltrankt year
		reshape wide meanpermearnaltranktp5 , i(permearnaltrankt) j(year)
		gen idex = _n
		
		*T+5
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{			
			gen y1 = 93 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 93 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 93
			local t2pos = 85 
			
		}
		else{
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		}
		tw  (line meanpermearnaltranktp51985 meanpermearnaltranktp51995 meanpermearnaltranktp52005 permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue green black) lpattern(solid shortdash_dot longdash_dot dash) lwidth(thick thick thick )) ///
			(scatter meanpermearnaltranktp51985 meanpermearnaltranktp51995 meanpermearnaltranktp52005 permearnaltrankt if idex==42, ///
			color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(${marksize}) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of `=ustrunescape("\u0050\u0303")'{sub:it}", place(w) size(${xtitlesize}))  ///
			legend(ring(0) position(11) order(1 "1985" 2 "1995" 3 "2005") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentiles of Permanent Income, `=ustrunescape("\u0050\u0303")'{sub:it}", size(${xtitlesize})) title("", color(black) size(${titlesize})) ///
			xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 99 "99.9", labsize(${xlabsize}) grid)  ///
			graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentiles of `=ustrunescape("\u0050\u0303")'{sub:it+5}", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))									
			graph export "${folderfile}/fig7_mobility_male`mm'_yrs_T5.pdf", replace 
			
		*T+10
		insheet using "$maindir/figurescsv/${mobidata}/L_male_agegp_permearnalt_mobstat.csv", clear
		
		keep if male == `mm'
		collapse meanpermearnaltranktp10 [aw=npermearnaltranktp10], by(permearnaltrankt year)
		keep meanpermearnaltranktp10 permearnaltrankt year
		reshape wide meanpermearnaltranktp10 , i(permearnaltrankt) j(year)
		gen idex = _n
		
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{	
			gen y1 = 88 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 88 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 88
			local t2pos = 85 
				   			
		}
		else{			
			gen y1 = 90 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 90 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 90
			local t2pos = 85 

		}
			
		tw  (line meanpermearnaltranktp101985 meanpermearnaltranktp101995 meanpermearnaltranktp102005 permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue green black) lpattern(solid shortdash_dot longdash dash) lwidth(thick thick thick)) ///
			(scatter meanpermearnaltranktp101985 meanpermearnaltranktp101995 meanpermearnaltranktp102005 permearnaltrankt permearnaltrankt if idex==42, ///
			color(red blue green) lpattern(dash dash dash) msymbol(D S O none)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(${marksize}) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of `=ustrunescape("\u0050\u0303")'{sub:it}", place(w) size(${xtitlesize}))  ///
			legend(ring(0) position(11) order(1 "1985" 2 "1995" 3 "2005") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentiles of Permanent Income, `=ustrunescape("\u0050\u0303")'{sub:it}", size(${xtitlesize})) title("", color(black) size(${titlesize})) ///
			xlabel(0(10)90 99, labsize(${xlabsize}) grid) graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentiles of `=ustrunescape("\u0050\u0303")'{sub:it+10}", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))			
			graph export "${folderfile}/fig7_mobility_male`mm'_yrs_T10.pdf", replace 
		
	/*--- Mobility by age group---*/			
				
		/*Load Data*/
		insheet using "$maindir/figurescsv/${mobidata}/L_male_agegp_permearnalt_mobstat.csv", clear
		
		keep if male == `mm'
		collapse meanpermearnaltranktp5, by(permearnaltrankt agegp)
		keep meanpermearnaltranktp5 permearnaltrankt agegp
		reshape wide meanpermearnaltranktp5 , i(permearnaltrankt) j(agegp)
		gen idex = _n
		
		/*T+5 mobility*/
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{			
			gen y1 = 93 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 93 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 93
			local t2pos = 85 
		
		}
		else{
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		}
						
		tw  (line meanpermearnaltranktp51 meanpermearnaltranktp52 meanpermearnaltranktp53 permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue green black) lpattern(solid shortdash dash_dot dash) lwidth(thick thick thick)) ///
			(scatter meanpermearnaltranktp51 meanpermearnaltranktp52 meanpermearnaltranktp53 permearnaltrankt if idex==42, ///
			color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(${xtitlesize}) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of `=ustrunescape("\u0050\u0303")'{sub:it}", place(w) size(${xtitlesize}))  ///
			legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]" 3 "[45-55]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentiles of Permanent Income, `=ustrunescape("\u0050\u0303")'{sub:it}", size(${xtitlesize})) title("", color(black) size(${titlesize})) ///
			xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 99 "99.9", labsize(${xlabsize}) grid) ///
			graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentiles of `=ustrunescape("\u0050\u0303")'{sub:it+5}", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))						
			graph export "${folderfile}/fig7_mobility_male`mm'_T5.pdf", replace 
		
			 
		/*T+10 mobility*/
		insheet using "$maindir/figurescsv/${mobidata}/L_male_agegp_permearnalt_mobstat.csv", clear
		
		keep if male == `mm'
		collapse meanpermearnaltranktp10, by(permearnaltrankt agegp)
		keep meanpermearnaltranktp10 permearnaltrankt agegp
		reshape wide meanpermearnaltranktp10 , i(permearnaltrankt) j(agegp)
		gen idex = _n
		
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{	
			gen y1 = 88 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 88 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 88
			local t2pos = 85 
				   			
		}
		else{			
			gen y1 = 90 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 90 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 90
			local t2pos = 85 

		}	
		tw  (line meanpermearnaltranktp101 meanpermearnaltranktp102 permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue black) lpattern(solid shortdash_dot dash) lwidth(thick thick)) ///
			(scatter meanpermearnaltranktp101 meanpermearnaltranktp102 permearnaltrankt if idex==42, ///
			color(red blue green) lpattern(dash dash dash) msymbol(D S O)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(${marksize}) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of `=ustrunescape("\u0050\u0303")'{sub:it}", place(w) size(${xtitlesize}))  ///
			legend(ring(0) position(11) order(1 "[25-34]" 2 "[35-44]") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentiles of Permanent Income, `=ustrunescape("\u0050\u0303")'{sub:it}", size(${xtitlesize})) title("", color(black) size(${titlesize})) ///
			xlabel(0(10)90 99, labsize(${xlabsize}) grid) graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentiles of `=ustrunescape("\u0050\u0303")'{sub:it+10}", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))		
			graph export "${folderfile}/fig7_mobility_male`mm'_T10.pdf", replace 
	}	// END loop over men and women	
	
forvalues mm = 0/1	{ // GENDER LOOP
	
foreach rk of num 1 {	// SHORT/LONG TERM MOB LOOP FOR FIG18
	
// FIGURE 18

	*Load data of short term mobility
	if `mm' == 1 { // men
		insheet using "$maindir/figurescsv/${mobidata}/L_male_researn_mobstat.csv", clear
		keep if male == 1
		loc llabel = "men"
	}
	else { // women
		insheet using "$maindir/figurescsv/${mobidata}/L_male_researn_mobstat.csv", clear
		keep if male == 0
		loc llabel = "women"	
	}
	
		
	loc rk5 = `rk' + 4
	keep year researnrankt meanresearnranktp`rk' nresearnranktp`rk' meanresearnranktp`rk5' nresearnranktp`rk5'
	reshape wide meanresearnranktp`rk' nresearnranktp`rk' meanresearnranktp`rk5' nresearnranktp`rk5', i(researnrankt) j(year) 
	gen idex = _n
	
	cap: drop  y1 x1 y2 x2
	if `mm' == 1{			
		gen y1 = 93 if _n == 1
		gen x1 = 85 if _n == 1
		gen y2 = 93 if _n == 1
		gen x2 = 97 if _n == 1
		local t1pos = 93
		local t2pos = 85 
		
	}
	else{
		gen y1 = 95 if _n == 1
		gen x1 = 85 if _n == 1
		gen y2 = 95 if _n == 1
		gen x2 = 97 if _n == 1
		local t1pos = 95
		local t2pos = 85 
	}
	
			
	local formatfile = "${formatfile}"			// format of saved file 
	local folderfile = "${folderfile}"			// folder where the plot is saved	


tw  (line meanresearnranktp`rk'2005 meanresearnranktp`rk5'2005 researnrankt researnrankt if idex<= 41, ///
			color(red blue black) lpattern(solid shortdash_dot dash) lwidth(thick thick thin)) ///
			(scatter meanresearnranktp`rk'2005 meanresearnranktp`rk5'2005 researnrankt researnrankt if idex==42, ///
			color(red blue none) lpattern(dash dash) msymbol(D S )  msize(large large ) ) ///
			(pcarrow y1 x1 y2 x2, msize(${marksize}) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of {&epsilon}{sub:t}", place(w) size(${xtitlesize}))  ///
			legend(ring(0) position(4) order(1 "One-Year Mobility" 2 "Five-Year Mobility" 3 "45{sup:o} line") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			ytitle("Mean Percentile for {&epsilon}{sub:t} in year t+`rk' and t+`rk5'", axis(1) size(${ytitlesize})) ylabel(,axis(1) labsize(${ylabsize}) )  ///
			xtitle("Percentile for {&epsilon}{sub:t} in year t",size(${xtitlesize})) xlabel(,grid labsize(${xlabsize}) ) ///
			xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 99 "99", grid labsize(${xlabsize}) ) ///
			graphregion(color(white)) plotregion(lcolor(black)) //												
			graph export `folderfile'/fig11a_researn_`rk'y_`rk5'y_mobility_T_`llabel'.`formatfile', replace
			

			
} // END OF SHORT/LONG TERM MOB LOOP FOR FIG18

		
			
} // END OF GENDER LOOP
	

// Figure A27 //
forvalues mm = 0/1	{ // GENDER LOOP
	
foreach rk of num 5 {	// SHORT/LONG TERM MOB LOOP FOR FIG18
	


	*Load data of short term mobility
	if `mm' == 1 { // men
		insheet using "$maindir/figurescsv/${mobidata}/L_male_researn_mobstat.csv", clear
		keep if male == 1
		loc llabel = "men"
	}
	else { // women
		insheet using "$maindir/figurescsv/${mobidata}/L_male_researn_mobstat.csv", clear
		keep if male == 0
		loc llabel = "women"	
	}
	
	keep year researnrankt meanresearnranktp`rk' nresearnranktp`rk'
	reshape wide meanresearnranktp`rk' nresearnranktp`rk', i(researnrankt) j(year) 
	gen idex = _n
	
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{			
			gen y1 = 96 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 96 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 96
			local t2pos = 85 
			
		}
		else{
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		}
		tw  (line meanresearnranktp`rk'1985 meanresearnranktp`rk'1995 meanresearnranktp`rk'2005 researnrankt researnrankt if idex<= 41, ///
			color(red blue green black) lpattern(solid shortdash_dot longdash_dot dash) lwidth(thick thick thick )) ///
			(scatter meanresearnranktp`rk'1985 meanresearnranktp`rk'1995 meanresearnranktp`rk'2005 researnrankt researnrankt if idex==42, ///
			color(red blue green black) lpattern(dash dash dash none) msymbol(D S O none)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(${marksize}) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of {&epsilon}{sub:t}", place(w) size(${xtitlesize}) )  ///
			legend(ring(0) position(11) order(1 "1985" 2 "1995" 3 "2005") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentile for {&epsilon}{sub:t} in year t", size(${xtitlesize})) title("", color(black) size(${titlesize})) ///
			xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 99 "99", labsize(${xlabsize}) grid) ///
			graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentile for {&epsilon}{sub:t} in year t+`rk'", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))									
			graph export "${folderfile}/fig11a_researn_`rk'y_mobility_T_`llabel'.pdf", replace 
			
} // END OF SHORT/LONG TERM MOB LOOP 
}

	
	*What is the folder to save files 

	gl folderfile = "$maindir/${outfolder}"


forvalues mm = 0/1	{ // GENDER LOOP
	
foreach rk of num 5 {	// SHORT/LONG TERM MOB LOOP FOR FIG18
	


	*Load data of short term mobility
	if `mm' == 1 { // men
		insheet using "$maindir/figurescsv/${mobidata}/L_male1_permearnalt_mobstat_T5T10.csv", clear
		keep if male == 1
		loc llabel = "men"
	}
	else { // women
		insheet using "$maindir/figurescsv/${mobidata}/L_male0_permearnalt_mobstat_T5T10.csv", clear
		keep if male == 0
		loc llabel = "women"	
	}
	
// 	keep year researnrankt meanresearnranktp`rk' nresearnranktp`rk'
// 	reshape wide meanresearnranktp`rk' nresearnranktp`rk', i(researnrankt) j(year) 
// 	gen idex = _n

	
	
	loc rk10 = `rk' + 5
		cap: drop  y1 x1 y2 x2
		if `mm' == 1{			
			gen y1 = 96 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 96 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 96
			local t2pos = 85 
			
		}
		else{
			gen y1 = 95 if _n == 1
			gen x1 = 85 if _n == 1
			gen y2 = 95 if _n == 1
			gen x2 = 97 if _n == 1
			local t1pos = 95
			local t2pos = 85 
		}
		
		graph set window fontface "${fontface}"
		tw  (line meanpermearnaltranktp`rk' meanpermearnaltranktp`rk10' permearnaltrankt permearnaltrankt if idex<= 41, ///
			color(red blue black) lpattern(solid shortdash_dot dash) lwidth(thick thick medthick)) ///
			(scatter meanpermearnaltranktp`rk' meanpermearnaltranktp`rk10' permearnaltrankt permearnaltrankt if idex==42, ///
			color(red blue black) lpattern(dash dash dash none) msymbol(D S none)  msize(large large large) ) ///
			(pcarrow y1 x1 y2 x2, msize(medlarge) mlwidth(medthick) mlcolor(black) lcolor(black) ), ///
			text(`t1pos' `t2pos' "Top 0.1% of `=ustrunescape("\u0050\u0303")'{sub:it}", place(w) size(${xtitlesize}))  ///
			legend(ring(0) position(11) order(1 "Five-year mobility" 2 "Ten-year mobility" 3 "45{sup:o} line") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			xtitle("Percentile for `=ustrunescape("\u0050\u0303")'{sub:it} in year t", size(${xtitlesize})) title("", color(black) size(${titlesize})) ///
			xlabel(2.5 "0" 10 "10" 20 "20" 30 "30" 40 "40" 50 "50" 60 "60" 70 "70" 80 "80" 90 "90" 99 "99", labsize(${xlabsize}) grid) ///
			graphregion(color(white)) plotregion(lcolor(black)) ///
			ytitle("Mean Percentile for `=ustrunescape("\u0050\u0303")'{sub:it} in year t+`rk' and t+`rk10'", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize})) name(g`mm',replace) 				
			
			graph export "${folderfile}/fig11a_permearn_`rk'y_`rk10'y_mobility_T_`llabel'.pdf", replace fontface("${fontface}") as(pdf) name(g`mm')
//			
} // END OF SHORT/LONG TERM MOB LOOP 
}

	
}
 
/*---------------------------------------------------	
  Figures: Cohorts and initial inequality
  Using: gkswplot1rece, tspltAREALimPA, tspltAREALim5  
 ---------------------------------------------------*/	

if "${figcoh}" == "yes"{ 

	*What is the folder to save plot?
	gl folderfile = "$maindir/${outfolder}"
	

foreach var in logearn{	// Add here other variables 
	foreach subgp in fem male {			// Add here other groups 
				
				
// Plots by cohorts (as in Guvenen, Kaplan, Song, and Weidner, 2018)	
			
	*Which variable is under analysis? 
	*The code generates for raw earnings and residuals earnings
	gl vari = "`var'"		
	
	*Label for plots
	local labtitle = "log y{sub:it}"
								
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_age_sumstat.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_maleage_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
	}
		
	if "`subgp'" == "fem"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_maleage_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
	}
	
	*Calculate additional moments 
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p9010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25
	
	gen rece3 = inlist(year,${receyears})*1
	gen rece4 = inlist(year,${receyears})*10
	
	
	gkswplot1rece "p50`var'" "year" ///
			 "1985 1990 1995 2000 2005 2010" /// what cohorts?
			 "25 30 35" /// What ages: code allows three
			 "${yrfirst}" "${yrlast}" "3" /// x-axis
			 "on" "11" "1" "Age 25" "Age 30" "Age 35" /// Legends
			 "Year" "Percentiles of log (y{sub:it})"  /// x and y titles 
			 "" "large" "" "" ///
			 "fig14_gksw_p50logearn_`subgp'" ///
			 "9.8" "11.2" "0.4" //
	
	
	gkswplot1rece "p10`var'" "year" ///
			 "1985 1990 1995 2000 2005 2010" /// what cohorts?
			 "25 30 35" /// What ages: code allows three
			 "${yrfirst}" "${yrlast}" "3" /// x-axis
			 "on" "11" "1" "Age 25" "Age 30" "Age 35" /// Legends
			 "Year" "Percentiles of log (y{sub:it})"  /// x and y titles 
			 "" "large" "" "" ///
			 "fig14_gksw_p10`var'_`subgp'"	///
			 "8.6" "10" "0.2" //
		
	gkswplot1rece "p90`var'" "year" ///
			 "1985 1990 1995 2000 2005 2010" /// what cohorts?
			 "25 30 35" /// What ages: code allows three
			 "${yrfirst}" "${yrlast}" "3" /// x-axis
			 "on" "11" "1" "Age 25" "Age 30" "Age 35" /// Legends
			 "Year" "Percentiles of log (y{sub:it})"  /// x and y titles 
			 "" "large" "" "" ///
			 "fig14_gksw_p90`var'_`subgp'"	///
			 "10.6" "11.9" "0.4" //
			 
	gkswplot1rece "p9010`var'" "year" ///
			 "1985 1990 1995 2000 2005 2010" /// what cohorts?
			 "25 30 35" /// What ages: code allows three
			 "${yrfirst}" "${yrlast}" "3" /// x-axis
			 "on" "1" "1" "Age 25" "Age 30" "Age 35" /// Legends
			 "Year" "P90-P10 of log (y{sub:it})"  /// x and y titles 
			 "" "large" "" "" ///
			 "fig14_gksw_p9010`var'_`subgp'" ///
			 "1.8" "2.3" "0.1" //
		
		
// Plots at the age of entry

	foreach ageval in 25 30 35{
	preserve
		*Keep only the sub sample at the age of age val 
		keep if age == `ageval'
		
		*Rescale by first year 
		foreach vv in sd$vari p1$vari p2_5$vari p5$vari p10$vari p12_5$vari p25$vari ///
			p37_5$vari p50$vari p62_5$vari p75$vari p87_5$vari p90$vari p95$vari ///
			p97_5$vari p99$vari {
			
			sum  `vv' if year == ${yrfirst}, meanonly
			gen n`vv' = `vv' - r(mean)
			
			}
		*Recessions bars 
		gen rece = inlist(year,${receyears})

		*What is the last year in the x axis 
		local rlast = ${yrlast}

	// 	*Plots
		
	// Percentiles
	

	tspltAREALimPA "p90$vari p75$vari p50$vari p25$vari p10$vari" /// Which variables?
	   "year" ///
	   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "5" "7" ///
	   "Workers at Age `ageval'" /// x axis title
	   "Percentiles of `labtitle'" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig12a_`subgp'_`ageval'_${vari}"	/// Figure name
	    "8" "12" "1"	/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D"  //
				
		

	tspltAREALimPA "np90$vari np75$vari np50$vari np25$vari np10$vari" /// Which variables?
	   "year" ///
	   ${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
	   "p90" "p75" "p50" "p25" "p10" "" "" "" "" /// Labels 
	   "1" "11" ///
	   "Workers at Age `ageval'" /// x axis title
	   "Percentiles Relative to ${yrfirst}" /// y axis title 
	   "" ///  Plot title
	   "" ///
	   "fig12a_`subgp'_`ageval'_n${vari}"	/// Figure name
	    "-.3" ".5" ".2"	/// ylimits
	   "" 						/// Set to off to have inactive legend
	   "blue green red navy black maroon forest_green purple gray orange"			/// Colors
	   "O + S x D"  //

		
	restore
	} // END of loop over age val
		   
		   
}	// END loop subgroups
}	// END loop over variables 
}
	
	
/*---------------------------------------------------	
  Figure: Age cohorts combined for men and women
  Using: tspltAREALim5  
 ---------------------------------------------------*/	

if "${figcoh_comb}" == "yes"{ 

	*What is the folder to save plot?
	gl folderfile = "$maindir/${outfolder}"
	

foreach var in logearn{	// Add here other variables 
	foreach subgp in fem male {			// Add here other groups 
				
				
// Plots by cohorts (as in Guvenen, Kaplan, Song, and Weidner, 2018)	
			
	*Which variable is under analysis? 
	*The code generates for raw earnimgs and residuals earnigs
	gl vari = "`var'"		
	
	*Label for plots
	local labtitle = "log y{sub:it}"
								
	*You can add more groups to this section 
	if "`subgp'" == "all"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_age_sumstat.csv", clear
		local tlocal = "All Sample"
	}
	if "`subgp'" == "male"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_maleage_sumstat.csv", clear
		keep if male == 1	// Keep the group we want to plot 
		local tlocal = "Men"
	}
		
	if "`subgp'" == "fem"{
		insheet using "$maindir/figurescsv/${ineqdata}/L_`var'_maleage_sumstat.csv", clear
		keep if male == 0	// Keep the group we want to plot 
		local tlocal = "Women"
	}
	
	*Calculate additional moments 
	gen p9010${vari} = p90${vari} - p10${vari}
	gen p9050${vari} = p90${vari} - p50${vari}
	gen p5010${vari} = p50${vari} - p10${vari}
	gen ksk${vari} = (p9050${vari} - p9010${vari})/p9010${vari}

	*Gen cohort that is the age at which cohort was 25 years old 
	gen cohort25 = year - age + 25
	order year age cohort25
		
// Plots at the age of entry

	
	keep if age == 25 | age==30 | age==35
	
	ds year age, not
	reshape wide `r(varlist)', i(year) j(age)

	
	*What is the last year in the x axis 
	local rlast = ${yrlast}

	// 	*Plots
	
    gen rece = inlist(year,${receyears})
	
	local rlast = ${yrlast}

	tspltAREALim5 "p9010${vari}25 p9010${vari}35 p9050${vari}25 p9050${vari}35 p5010${vari}25 p5010${vari}35" /// Which variables?
		   "year" ///
			${yrfirst} `rlast' 3 /// Limits of x and y axis. Example: x axis is -.1(0.05).1 
		   "P90-P10 (age 25)" "P90-P10 (age 35)" "P90-P50 (age 25)" "P90-P50 (age 35)" "P50-P10 (age 25)" "P50-P10 (age 35)" "" "" "" /// Labels 
		   "2" "11" ///
		   "" /// x axis title
		   "" /// y axis title 
		   "" ///  Plot title
		   ""  /// 	 Plot subtitle  
		   "fig12b_`subgp'_2535_${vari}"	/// Figure name
			"0.5" "2.75" ".5"			/// ylimits
			"" 						/// If legend is active or nor	
		   "gold gold blue blue red red"			// Colors	  

		
	
	 // END of loop over age val
		   
		   
}	// END loop subgroups
}	// END loop over variables 
}

 
/*---------------------------------------------------
  Figure: Tail figures
----------------------------------------------------*/

if "${figtail}" == "yes"{
	
	gl folderfile = "$maindir/${outfolder}" 
	
	*Load and reshape data 		
	local mm = 2 
				
		if `mm' == 1{
			insheet using "$maindir/figurescsv/${ineqdata}/RI_male_earn_idex.csv", clear comma 
			keep if male == `mm'
			local llabel = "Male"
		}
		else if `mm' == 0{
			insheet using "$maindir/figurescsv/${ineqdata}/RI_male_earn_idex.csv", clear comma 
			keep if male == `mm'
			local llabel = "Women"		
		}
		else {
			insheet using "$maindir/figurescsv/${ineqdata}/RI_earn_idex.csv", clear comma 	
			local llabel = "all"
		}
				
		reshape long t me ra ob, i(year) j(level) string
		split level, p(level) 
		drop level1
		rename level2 numlevel
		destring numlevel, replace 
		order numlevel level year 
		sort year numlevel
		
		*Re scale and share of pop
		by year: gen aux = 20*ob if numlevel == 0 
		by year: egen tob = max(aux)   // Because ob is number of observations in top 5%
		drop aux
		by year: gen  shob = ob/tob
				 gen  lshob = log(shob)		  	
		
		gen t1000s = (t/1000)/${exrate2018}				// Tranform to dollars of 2018
		gen lt1000s = log(t1000s)
		gen lt = log(t)
		gen l10t = log10(t)
		
		*Re-reshape 
		reshape wide t me ra ob tob shob lshob t1000s lt l10t lt1000s, i(numlevel) j(year)
		
				
		/*5% Tail*/
		regress lshob1995 lt1995
		predict lshob1995_hat, xb
		gl slopep1995 : di %4.2f _b[lt1995]
		
		regress lshob2015 lt2015
		predict lshob2015_hat, xb
		gl slopep2015 : di %4.2f _b[lt2015]
		
		regress lshob1985 lt1985
		predict lshob1985_hat, xb
		gl slopep1985 : di %4.2f _b[lt1985]

		
		tw (line lshob1985 lshob1985_hat lt1985, color(green green) lwidth(thick) lpattern(solid dash)) ///
		   (line lshob1995 lshob1995_hat lt1995, color(red red) lwidth(thick) lpattern(solid dash)) ///
		   (line lshob2015 lshob2015_hat lt2015, color(blue blue)  lwidth(thick) lpattern(solid dash)) , ///
		legend(ring(0) position(2) ///
			order(1 "1985 Level (Slope: ${slopep1985})" 3 "1995 Level (Slope: ${slopep1995})" 5 "2015 Level (Slope: ${slopep2015})") size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			 xtitle("log y{sub:it}", size(${xtitlesize})) title(, color(black) size(${titlesize})) ///
			  xlabel(, grid labsize(${xlabsize})) graphregion(color(white)) plotregion(lcolor(black)) ///
			 ytitle("log(1-CDF)", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))
			 graph export "${folderfile}/logCDF_5pct_`llabel'.pdf", replace 
		drop lshob2015_hat lshob1995_hat lshob1985_hat
        
		
			
		/*1% Tail*/		
		regress lshob1995 lt1995 if shob1995 < 0.01
		predict lshob1995_hat if e(sample), xb
		gl slopep1995 : di %4.2f _b[lt1995]
		
		regress lshob2015 lt2015 if shob2015 < 0.01
		predict lshob2015_hat if e(sample), xb
		gl slopep2015 : di %4.2f _b[lt2015]
		
		regress lshob1985 lt1985 if shob1985 < 0.01
		predict lshob1985_hat if e(sample), xb
		gl slopep1985 : di %4.2f _b[lt1985]

		   
		tw (line lshob1985 lshob1985_hat lt1985  if shob1985 < 0.01, color(green green) lwidth(thick) lpattern(solid dash)) ///
		   (line lshob1995 lshob1995_hat lt1995  if shob1995 < 0.01, color(red red) lwidth(thick) lpattern(solid dash)) ///
		   (line lshob2015 lshob2015_hat lt2015  if shob2015 < 0.01, color(blue blue)  lwidth(thick) lpattern(solid dash)) , ///
		legend(ring(0) position(2) order(1 "1985 Level (Slope: ${slopep1985})" 3 "1995 Level (Slope: ${slopep1995})" 5 "2015 Level (Slope: ${slopep2015})") ///
		size(${legesize}) cols(1) symxsize(7) region(color(none))) ///
			 xtitle("log y{sub:it}", size(${xtitlesize})) title(, color(black) size(${titlesize})) ///
			  xlabel(, grid labsize(${xlabsize})) graphregion(color(white)) plotregion(lcolor(black)) ///
			 ytitle("log(1-CDF)", color(black) size(${ytitlesize})) ylabel(,labsize(${ylabsize}))
			 graph export "${folderfile}/logCDF_1pct_`llabel'.pdf", replace 
		drop lshob2015_hat lshob1995_hat lshob1985_hat

		
}

/*-------------------------------------------------------
  Figures: Density plots
  Using: logdnplot
--------------------------------------------------------*/

if "${figden}" == "yes"{ 
	
	*Folder to save figures 
	gl folderfile = "$maindir/${outfolder}"
	
	*Ploting
	foreach sam in women men {
		foreach yy in 2005{			// Which years are being plotted
			foreach vari in researn1F researn5F    {
			
				*Labels 
				if "`vari'" == "researn1F"{
 					local labtitle = "{&Delta}{sup:1}{&epsilon}{sub:it}"
				}
				if "`vari'" == "researn5F"{
 					local labtitle = "{&Delta}{sup:5}{&epsilon}{sub:it}"
				}
			
				*Data
				if "`sam'" == "all"{
					insheet using "$maindir/figurescsv/${voladata}/L_`vari'_sumstat.csv", case clear
					
					sum sd`vari' if year == `yy'
					gl sd = r(mean) 
					
					sum skew`vari' if year == `yy'
					gl skew = r(mean) 
								
					sum kurt`vari' if year == `yy'
					gl kurt = r(mean) 
					
					gl sdplot: di %4.2f  ${sd}
					gl skplot: di %4.2f  ${skew}
					gl kuplot: di %4.2f  ${kurt}
					
					insheet using "$maindir/figurescsv/${voladata}/L_`vari'_hist.csv", case clear
					local labtitle2 = "(All Sample)"
				}
				else if "`sam'" == "men"{
					insheet using "$maindir/figurescsv/${voladata}/L_`vari'_male_sumstat.csv", case clear
					
					sum sd`vari' if year == `yy' & male == 1
					gl sd = r(mean) 
					
					sum skew`vari' if year == `yy' & male == 1
					gl skew = r(mean) 
								
					sum kurt`vari' if year == `yy' & male == 1
					gl kurt = r(mean) 
					
					gl sdplot: di %4.2f  ${sd}
					gl skplot: di %4.2f  ${skew}
					gl kuplot: di %4.2f  ${kurt}
					
					
					insheet using "$maindir/figurescsv/${voladata}/L_`vari'_hist_male.csv", case clear
					keep if male == 1
					local labtitle2 = "(Men Only)"
				}
				else if "`sam'" == "women"{
					insheet using "$maindir/figurescsv/${voladata}/L_`vari'_male_sumstat.csv", case clear
					
					sum sd`vari' if year == `yy' & male == 0
					gl sd = r(mean) 
					
					sum skew`vari' if year == `yy' & male == 0
					gl skew = r(mean) 
								
					sum kurt`vari' if year == `yy' & male == 0
					gl kurt = r(mean) 
					
					gl sdplot: di %4.2f  ${sd}
					gl skplot: di %4.2f  ${skew}
					gl kuplot: di %4.2f  ${kurt}
					
					insheet using "$maindir/figurescsv/${voladata}/L_`vari'_hist_male.csv", case clear
					keep if male == 0
					local labtitle2 = "(Women Only)"
				}
				
				
				*Log densities 
				gen lden_`vari'`yy' = log(den_`vari'`yy')
				gen lnden_`vari'`yy' = log(normalden(val_`vari'`yy',0,${sd}))
				
				gen nden_`vari'`yy' = (normalden(val_`vari'`yy',0,${sd}))
				
				*Slopes
				reg lden_`vari'`yy' val_`vari'`yy' if val_`vari'`yy' < -1 & val_`vari'`yy' > -4
				gl blefttail: di %4.2f _b[val_`vari'`yy']
				predict lefttail if e(sample), xb 
				
				reg lden_`vari'`yy' val_`vari'`yy' if val_`vari'`yy' > 1 & val_`vari'`yy' < 4
				gl brighttail: di %4.2f _b[val_`vari'`yy']
				predict righttail if e(sample), xb 
				
				*Trimming for plots
				replace lnden_`vari'`yy' = . if val_`vari'`yy' < -2
				replace lnden_`vari'`yy' = . if val_`vari'`yy' > 2
				
				replace lden_`vari'`yy' = . if val_`vari'`yy' < -4
				replace lden_`vari'`yy' = . if val_`vari'`yy' > 4
				
				
				replace nden_`vari'`yy' = . if val_`vari'`yy' < -4
				replace nden_`vari'`yy' = . if val_`vari'`yy' > 4
				
				replace den_`vari'`yy' = . if val_`vari'`yy' < -4
				replace den_`vari'`yy' = . if val_`vari'`yy' > 4
				
				replace lefttail = . if val_`vari'`yy' < -4
				replace lden_`vari'`yy' = . if val_`vari'`yy' > 4
				
				replace righttail = . if val_`vari'`yy' > 4
				replace lden_`vari'`yy' = . if val_`vari'`yy' > 4
				
				
				logdnplot "lden_`vari'`yy' lnden_`vari'`yy' lefttail righttail" "val_`vari'`yy'" /// y and x variables 
						"`labtitle'" "Log-Density" "medium" "medium" 		/// x and y axcis titles and sizes 
						 "" "" "large" ""  ///	Plot title
						 "Data Density" "N(0,${sdplot}{sup:2})" "Left   Slope: ${blefttail}" "Right Slope: ${brighttail}" "" ""						/// Legends
						 "on" "11"	"1"							/// Leave empty for active legend
						 "-4" "4" "1" "-10" "3" "2"				/// Set limits of x and y axis 
						 "lden_`vari'`yy'"					    /// Set what variable defines the y-axis
						"fig13_lden_`vari'_`sam'_`yy'"			/// Name of file
						"St. Dev.: ${sdplot}" "Skewness: ${skplot}"  "Kurtosis: ${kuplot}" ///
						 "2 1.8" "1 1.8" "0 1.8"				// Position of the right text
						 										
				logdnplot "den_`vari'`yy' nden_`vari'`yy'" "val_`vari'`yy'" /// y and x variables 
						"`labtitle'" "Density" "medium" "medium" 		/// x and y axcis titles and sizes 
						 "" "" "large" ""  ///	Plot title
						 "Data Density" "N(0,${sdplot}{sup:2})" "" "" "" ""						/// Legends
						 "on" "11"	"1"							/// Leave empty for active legend
						 "-2.5" "2.5" "1" "0" "4" "1"				/// Set limits of x and y axis 
						 "den_`vari'`yy'"					/// Set what variable defines the y-axis
						"fig13_den_`vari'_`sam'_`yy'"		/// Name of file
						"St. Dev.: ${sdplot}" "Skewness: ${skplot}"  "Kurtosis: ${kuplot}" ///
						 "3.0 1" "2.5 1" "2.0 1"							 				
			
			}	// END loop over variables	
		}	// END loop over years 
	}	// END loop over samples
} 	// END of section

*END OF THE CODE
