// plotting setup
//_______________________________________________
graph set window fontface "Times New Roman"

local base0 graphregion(color(white)) legend(region(lcolor(white))) ytitle("") ylabel(, labsize(medlarge) grid) xlabel(, labsize(medlarge) grid)

local base1 mcol(blue) mfcol(blue*0.25) mlcol(blue) lcol(blue) msymbol(D) lwidth(*2) `base0'
local base2 mcol(blue red) mfcol(blue*0.25 red*0.25) mlcol(blue red) lcol(blue red) msymbol(D S) lwidth(*2 *2) `base0'
local base3 mcol(blue red green) mfcol(blue*0.25 red*0.25 green*0.25) mlcol(blue red green) lcol(blue red green) msymbol(D S T) lwidth(*2 *2 *2) `base0'
local base4 mcol(blue red green maroon) mfcol(blue*0.25 red*0.25 green*0.25 maroon*0.25) mlcol(blue red green maroon) lcol(blue red green maroon) msymbol(D S T O) lwidth(*2 *2 *2 *2) `base0'
local base5 mcol(blue red green maroon navy) mfcol(blue*0.25 red*0.25 green*0.25 maroon*0.25 navy*0.25) mlcol(blue red green maroon navy) lcol(blue red green maroon navy) msymbol(D S T O X) lwidth(*2 *2 *2 *2 *2) `base0'

local sbase1 mcol(blue) mfcol(blue*0.25) mlcol(blue) lcol(blue) msymbol(D) lwidth(*2)
local sbase2 mcol(red) mfcol(red*0.25) mlcol(red) lcol(red) msymbol(S) lwidth(*2)
local sbase3 mcol(green) mfcol(green*0.25) mlcol(green) lcol(green) msymbol(T) lwidth(*2)
local sbase4 mcol(maroon) mfcol(maroon*0.25) mlcol(maroon) lcol(maroon) msymbol(O) lwidth(*2)
local sbase5 mcol(navy) lcol(navy) msymbol(X) lwidth(*2)

// xlabel (medlarge, large, vlarge, huge, vhuge etc)
local empxlabel xlabel(1 "[5,10)" 2 "[10,20)" 3 "[20,100)" 4 "[100,1000)" 5 "≥1000", labsize(medlarge) grid)
local lpxlabel xlabel(, labsize(medlarge) grid)

// xtitle
local empxtitle xtitle("Employment", size(medlarge))
local lpxtitle xtitle("Log Labor Productivity Residual Quintile", size(medlarge))

local dempxtitle  xtitle("Average Employment Growth by Decile", size(medlarge))
local dlpxtitle xtitle("Average Labor Productivity Residual Growth by Decile", size(medlarge))

local permempxtitle xtitle("Permanent Employment", size(medlarge))
local permlpxtitle xtitle("Log Permanent Labor Productivity Residual Quintile", size(medlarge))


// ytitle
local meanyleveltitle ytitle("Average of {&epsilon}{sub:it}", size(medlarge))
local meanytitle ytitle("Average of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))
local p9010ytitle ytitle("P90-P10 of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))
local p9050ytitle ytitle("P90-P50 of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))
local p5010ytitle ytitle("P50-P10 of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))

local dispersionytitle ytitle("Dispersion of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))

local fracytitle ytitle("Fraction of Dropout Workers", size(medlarge))

local meanemptitle ytitle("Average Employment Growth", size(medlarge))

// legend
local sexlegend legend(order(1 "All" 2 "Male" 3 "Female") row(1) region(lcolor(white)) size(medlarge))

local dispersionlegend legend(order(1 "P90-P50" 2 "P50-P10") row(1) region(lcolor(white)) size(medlarge))

local yearlegend legend(order(1 "Years 2001–2007" 2 "Years 2008–2011" 3 "Years 2012–2016") region(lcolor(white)) size(medlarge))
local agelegend legend(order(1 "Worker Ages 25–34" 2 "Worker Ages 35–44" 3 "Worker Ages 45–55") row(1) region(lcolor(white)) size(medlarge))
local entagelegend legend(order(1 "Firm Ages <10" 2 "Firm Ages 10–19" 3 "Firm Ages ≥20") region(lcolor(white)) size(medlarge))

local mover1legend legend(order(1 "Stayer" 2 "Non-laid-off Mover" 3 "Laid-off Mover") row(1) region(lcolor(white)) size(medlarge))

local emplegend legend(order(1 "[5,10)" 2 "[10,20)" 3 "[20,100)" 4 "[100,1000)" 5 "≥1000") row(2) region(lcolor(white)) size(medlarge))
local lplegend legend(order(1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Q5") row(1) region(lcolor(white)) size(medlarge))
local permearnlegend legend(order(1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Q5") row(1) region(lcolor(white)) size(medlarge))
local top_permearnlegend legend(order(1 "[P80,P90)" 2 "[P90,P99)" 3 "≥P99") row(1) region(lcolor(white)) size(medlarge))

local demplegend legend(order(1 "Low Employment Growth" 2 "Middle Employment Growth" 3 "High Employment Growth") region(lcolor(white)) size(medlarge))
local dlplegend legend(order(1 "Low Productivity Growth" 2 "Middle Productivity Growth" 3 "High Productivity Growth") region(lcolor(white)) size(medlarge))

// start
//____________________________________________________________________________
capture log close

log using $log/core.log, replace

local v emp
local g all
local h 1

use if `v'_group!=. & logearn_res!=. using $cleaned/workers_firms, clear

// avg earings level and firm size (Figure S32)
//_______________________________________________________________________
preserve
local s mean
local y logearn_res 
local filename `s'_`y'_by_`v'_level_`g'    
collapse (`s') `y', by(`v'_group)
twoway (connected `y' `v'_group, `base1' ``v'xlabel' ``v'xtitle' `meanyleveltitle')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    
restore

// fact 1: avg earings growth and firm size
//_______________________________________________________________________
// Figure 19(a)
preserve
local s mean
local y d`h'logearn_res
local filename `s'_`y'_by_`v'_level_`g'    
collapse (`s') `y', by(`v'_group)
twoway (connected `y' `v'_group, `base1' ``v'xlabel' ``v'xtitle' `meanytitle')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    
restore

// now keep only those with non-missing earnings growth
local y d`h'logearn_res
drop if `y'==.

// avg by movers vs. stayers (Figure 19(b))
//__________________________________________
preserve
local filename `s'_`y'_by_`v'_level_move_`g'
drop if mover`h'==.
collapse (`s') `y', by(`v'_group mover`h')
reshape wide `y', i(`v'_group) j(mover`h')
sort `v'_group
twoway (connected `y'0 `y'1 `y'2 `v'_group, `base3' ``v'xlabel' ``v'xtitle' `meanytitle' `mover1legend')
graph export $output/`filename'.pdf, replace	
save $output/`filename', replace
restore

// fraction of movers vs. stayers (Table 3)
//__________________________________________
preserve
local filename frac_move_by_`v'_level_`g'

drop if mover`h'==. // notice that mover1 is missing when layoff is not defined (year 2015)
gen stayer=(mover`h'==0)
gen non_laid_off_mover=(mover`h'==1)
gen laid_off_mover=(mover`h'==2)

local vars stayer non_laid_off_mover laid_off_mover

collapse (`s') `vars', by(`v'_group)
sort `v'_group
save $output/`filename', replace
restore

// fact 2: dispersion of earnings growth and firm size
//_______________________________________________________________________
preserve
collapse (p10) p10=`y' (p50) p50=`y' (p90) p90=`y', by(`v'_group)
gen p9010=p90-p10
gen p9050=p90-p50
gen p5010=p50-p10

drop p10 p50 p90

// overall (Figure 20(a))
local filename p9010_`y'_by_`v'_level_`g'    
twoway (connected p9010 `v'_group, `base1' ``v'xlabel' ``v'xtitle' `p9010ytitle')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    

// upper & lower (Figure S33(a))
local filename p9050_p5010_`y'_by_`v'_level_`g'
twoway (connected p9050 p5010 `v'_group, `base2' ``v'xlabel' `dispersionytitle' ``v'xtitle' `dispersionlegend')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    
restore

// dispersion by movers vs. stayers
//__________________________________________
preserve
drop if mover`h'==.
collapse (p10) p10=`y' (p50) p50=`y' (p90) p90=`y', by(`v'_group mover`h')
gen p9010=p90-p10
gen p9050=p90-p50
gen p5010=p50-p10
drop p10 p90

reshape wide p9010 p9050 p5010 p50, i(`v'_group) j(mover`h')
sort `v'_group

// overall (Figure 20(b))
local filename p9010_`y'_by_`v'_level_move_`g'
twoway (connected p90100 p90101 p90102 `v'_group, `base3' ``v'xlabel' ``v'xtitle' `p9010ytitle' `mover1legend')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace

// upper & lower: stayer (Figure S33(b))
local filename p9050_p5010_`y'_by_`v'_level_stayer_`g'
twoway (connected p90500 p50100 `v'_group, `base2' ``v'xlabel' ``v'xtitle' `dispersionytitle' `dispersionlegend')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    

// upper & lower: non-laid-off mover (Figure S33(c))
local filename p9050_p5010_`y'_by_`v'_level_non_laid_off_mover_`g'
twoway (connected p90501 p50101 `v'_group, `base2' ``v'xlabel' ``v'xtitle' `dispersionytitle' `dispersionlegend')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    

// upper & lower: laid-off mover (Figure S33(d))
local filename p9050_p5010_`y'_by_`v'_level_laid_off_mover_`g'
twoway (connected p90502 p50102 `v'_group, `base2' ``v'xlabel' ``v'xtitle' `dispersionytitle' `dispersionlegend')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    

restore

// fact 3: avg earnings growth and firm growth
//_______________________________________________________________________
drop if d`h'log`v'_group==. | d`h'log`v'==.
local s mean
local x d`h'log`v'

// everyone (Figure 21(a))
preserve
local filename `s'_`y'_by_`v'_growth`h'_`g'
collapse (`s') `y' `x', by(d`h'log`v'_group)
twoway (connected `y' `x', `base1' `d`v'xtitle' `meanytitle')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    
restore

// by mobility status (Figure 21(b))
preserve
drop if mover`h'==.
local filename `s'_`y'_by_`v'_growth`h'_move_`g'
collapse (`s') `y' `x', by(d`h'log`v'_group mover`h')
reshape wide `y' `x', i(d`h'log`v'_group) j(mover`h')
sort d`h'log`v'_group
twoway ///
(connected `y'0 `x'0, `sbase1') ///
(connected `y'1 `x'1, `sbase2') ///				
(connected `y'2 `x'2, `sbase3') ///
				, `base0' `d`v'xtitle' `meanytitle' `mover1legend'		
graph export $output/`filename'.pdf, replace
save $output/`filename', replace
restore

// by other groups: stayers only (Figures S36(a), 21(c), 21(d), and S36(b))
foreach w in `v' permearn top_permearn entage {
    
    preserve
    local filename `s'_`y'_by_`v'_growth`h'_`w'_stayer_`g'    
    keep if stayer`h'==1 & `w'_group!=.
    collapse (`s') `y' `x', by(d`h'log`v'_group `w'_group)
    reshape wide `y' `x', i(d`h'log`v'_group) j(`w'_group)
			
    if ("`w'"=="top_permearn" | "`w'"=="entage") {
        twoway ///
        (connected `y'1 `x'1, `sbase1') ///
        (connected `y'2 `x'2, `sbase2') ///
        (connected `y'3 `x'3, `sbase3') ///
					, `base0' `d`v'xtitle' `meanytitle' ``w'legend'
    }
    else {
        twoway ///
        (connected `y'1 `x'1, `sbase1') ///
        (connected `y'2 `x'2, `sbase2') ///
        (connected `y'3 `x'3, `sbase3') ///
        (connected `y'4 `x'4, `sbase4') ///
        (connected `y'5 `x'5, `sbase5') ///
					, `base0' `d`v'xtitle' `meanytitle' ``w'legend'
    }
    
    graph export $output/`filename'.pdf, replace    
    save $output/`filename', replace
    restore
}

// by lp growth: stayers only (Figure 22(a))
preserve
local filename `s'_`y'_by_`v'_growth`h'_lp_growth`h'_stayer_`g'
keep if stayer`h'==1 & d`h'loglp_group!=.

gen d`h'loglp_group2=.
replace d`h'loglp_group2=1 if inrange(d`h'loglp_group,1,3)
replace d`h'loglp_group2=2 if inrange(d`h'loglp_group,4,7)
replace d`h'loglp_group2=3 if inrange(d`h'loglp_group,8,10)

collapse (`s') `y' `x', by(d`h'log`v'_group d`h'loglp_group2)
reshape wide `y' `x', i(d`h'log`v'_group) j(d`h'loglp_group2)

twoway ///
(connected `y'1 `x'1, `sbase1') ///
(connected `y'2 `x'2, `sbase2') ///
(connected `y'3 `x'3, `sbase3') ///
				, `base0' `d`v'xtitle' `meanytitle' `dlplegend' ylabel(-0.2[0.1]0.2) xlabel(-1[0.5]1)
graph export $output/`filename'.pdf, replace
save $output/`filename', replace

restore

// by emp growth: stayers only (Figure 22(b))
preserve
local v lp
local x d`h'log`v'

local filename `s'_`y'_by_`v'_growth`h'_emp_growth`h'_stayer_`g'
keep if stayer`h'==1 & d`h'logemp_group!=.

gen d`h'logemp_group2=.
replace d`h'logemp_group2=1 if inrange(d`h'logemp_group,1,3)
replace d`h'logemp_group2=2 if inrange(d`h'logemp_group,4,7)
replace d`h'logemp_group2=3 if inrange(d`h'logemp_group,8,10)

collapse (`s') `y' `x', by(d`h'log`v'_group d`h'logemp_group2)
reshape wide `y' `x', i(d`h'log`v'_group) j(d`h'logemp_group2)

twoway ///
(connected `y'1 `x'1, `sbase1') ///
(connected `y'2 `x'2, `sbase2') ///
(connected `y'3 `x'3, `sbase3') ///
				, `base0' `d`v'xtitle' `meanytitle' `demplegend' ylabel(-0.2[0.1]0.2) xlabel(-1[0.5]1)
graph export $output/`filename'.pdf, replace
save $output/`filename', replace

restore

// fact 4: dispersion of earnings growth and firm growth
//_______________________________________________________________________
local v emp
local x d`h'log`v'

// everyone
//___________________
preserve
collapse (p10) p10=`y' (p50) p50=`y' (p90) p90=`y' (mean) `x', by(d`h'log`v'_group)
gen p9010=p90-p10
gen p9050=p90-p50
gen p5010=p50-p10

drop p10 p50 p90

// overall (Figure 23(a))
local filename p9010_`y'_by_`v'_growth`h'_`g'    
twoway (connected p9010 `x', `base1' `d`v'xtitle' `p9010ytitle')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    

// by mobility status
//___________________
preserve

drop if mover`h'==.

collapse (p10) p10=`y' (p50) p50=`y' (p90) p90=`y' (mean) `x', by(d`h'log`v'_group mover`h')
gen p9010=p90-p10
gen p9050=p90-p50
gen p5010=p50-p10
drop p10 p90

reshape wide p9010 p9050 p5010 p50 `x', i(d`h'log`v'_group) j(mover`h')
sort d`h'log`v'_group

// overall (Figure 23(b))
local filename p9010_`y'_by_`v'_growth`h'_move_`g'    

twoway ///
(connected p90100 `x'0, `sbase1') ///
(connected p90101 `x'1, `sbase2' yaxis(2)) ///				
(connected p90102 `x'2, `sbase3' yaxis(2)) ///
				, `base0' `d`v'xtitle' `p9010ytitle' legend(order(1 "Stayer (Left Axis)" 2 "Non-laid-off Mover (Right Axis)" 3 "Laid-off Mover (Right Axis)") region(lcolor(white)))
graph export $output/`filename'.pdf, replace
save $output/`filename', replace

// upper & lower: stayers only (Figure 23(c))
local filename p9050_p5010_`y'_by_`v'_growth`h'_stayer_`g'
capture drop p9050 p5010 `x'
gen p9050=p90500
gen p5010=p50100
gen `x'=`x'0
twoway (connected p9050 p5010 `x', `base2' `d`v'xtitle' `dispersionytitle' `dispersionlegend')
graph export $output/`filename'.pdf, replace
save $output/`filename', replace    

restore

// by other groups: stayers only (Figures S38(a), 23(d), S38(b))
foreach w in `v' permearn entage {

    preserve
    local filename p9010_`y'_by_`v'_growth`h'_`w'_stayer_`g'    
    keep if stayer`h'==1 & `w'_group!=.
    collapse (p10) p10=`y' (p90) p90=`y' (mean) `x', by(d`h'log`v'_group `w'_group)
    gen p9010=p90-p10
    drop p10 p90
    reshape wide p9010 `x', i(d`h'log`v'_group) j(`w'_group)
			
    if ("`w'"=="top_permearn" | "`w'"=="entage") {
        twoway ///
        (connected p90101 `x'1, `sbase1') ///
        (connected p90102 `x'2, `sbase2') ///
        (connected p90103 `x'3, `sbase3') ///
					, `base0' `d`v'xtitle' `p9010ytitle' ``w'legend'
    }
    else {
        twoway ///
        (connected p90101 `x'1, `sbase1') ///
        (connected p90102 `x'2, `sbase2') ///
        (connected p90103 `x'3, `sbase3') ///
        (connected p90104 `x'4, `sbase4') ///
        (connected p90105 `x'5, `sbase5') ///
					, `base0' `d`v'xtitle' `p9010ytitle' ``w'legend'
    }
    
    graph export $output/`filename'.pdf, replace    
    save $output/`filename', replace
    restore
}

capture log close
