capture log close
log using $log/firms.log, replace

use $cleaned/selected, clear

// collapse to entid level
collapse (mean) pd7_avgemp_12 total_revenue net_income_9369 naics6 bus_birth_year t4_payroll, by(year entid)

// create new variables
gen naics3 = floor(naics6/1000)
rename pd7_avgemp_12 emp

gen va = net_income_9369 + t4_payroll // value added
gen lp = va/emp // labour productivity
gen entage=year-bus_birth_year+1 //  firm age

keep emp lp entage entid naics3 year

sort entid year
xtset entid year

// construct permanent measures
//__________________________________
foreach v in lp emp {
	forval i=0/2{
		gen L`i'`v'=L`i'.`v'
		replace L`i'`v'=0 if L`i'`v'==.
		gen L`i'nonmissing=(L`i'.`v'!=.)
	}
	gen n_nonmissing=L0nonmissing+L1nonmissing+L2nonmissing
	gen perm`v'=(L0`v'+L1`v'+L2`v')/n_nonmissing
	replace perm`v'=. if n_nonmissing<2 | year<$min_year+2
	
	drop *nonmissing L*
}

// create residual labor prod measure
gen loglp = log(lp) if lp>0
reghdfe loglp, absorb(i.naics3#i.year) residuals(lp_res) 

gen logpermlp = log(permlp) if permlp>0
reghdfe logpermlp, absorb(i.naics3#i.year) residuals(permlp_res)

drop loglp logpermlp lp permlp
ren lp_res lp
ren permlp_res permlp

// level groups
//__________________________________
foreach v in lp permlp {
	gen `v'_group=.
	forval y=$min_year/$max_year {
		capture qui xtile aux = `v' if year==`y', nq(5)
		capture qui replace `v'_group=aux if year==`y'
		capture qui drop aux
	}

	by `v'_group, sort: egen mean_`v'=mean(`v')	
}

gen emp_group = .
replace emp_group = 1 if emp<10
replace emp_group = 2 if emp>=10 & emp<20
replace emp_group = 3 if emp>=20 & emp<100
replace emp_group = 4 if emp>=100 & emp<1000
replace emp_group = 5 if emp>=1000 & emp~=.

gen entage_group = .
replace entage_group = 1 if entage<10
replace entage_group = 2 if entage>=10 & entage<20
replace entage_group = 3 if entage>=20 & entage~=.

gen permemp_group = .
replace permemp_group = 1 if permemp<10
replace permemp_group = 2 if permemp>=10 & permemp<20
replace permemp_group = 3 if permemp>=20 & permemp<100
replace permemp_group = 4 if permemp>=100 & permemp<1000
replace permemp_group = 5 if permemp>=1000 & permemp~=.


sort entid year
xtset entid year

// log changes
//__________________________________
foreach h in 1 5 {
	qui gen d`h'loglp = F`h'.lp-lp
	qui gen d`h'logemp = log(F`h'.emp)-log(emp)
	
}

// log change groups
//__________________________________
foreach v in lp emp {
	foreach h in 1 5 {
		gen d`h'log`v'_group=.
		
		local max_y=$max_year-`h'
		
		forval y=$min_year/`max_y' {
			
			// within level quintile
			forval g=1/5 {
				capture noisily xtile aux = d`h'log`v' if year==`y' & `v'_group == `g', nq(10)
				capture noisily replace d`h'log`v'_group=aux if year==`y' & `v'_group == `g'
				capture noisily drop aux
			}
		}
		
		by d`h'log`v'_group, sort: egen mean_d`h'log`v'=mean(d`h'log`v')
	}
}

sort entid year
compress
save $cleaned/firms, replace

log close
