// plotting setup
//_______________________________________________
graph set window fontface "Times New Roman"

local base0 graphregion(color(white)) legend(region(lcolor(white))) ytitle("") ylabel(, labsize(medlarge) grid) xlabel(, labsize(medlarge) grid)

local base1 mcol(blue) mfcol(blue*0.25) mlcol(blue) lcol(blue) msymbol(D) lwidth(*2) `base0'
local base2 mcol(blue red) mfcol(blue*0.25 red*0.25) mlcol(blue red) lcol(blue red) msymbol(D S) lwidth(*2 *2) `base0'
local base3 mcol(blue red green) mfcol(blue*0.25 red*0.25 green*0.25) mlcol(blue red green) lcol(blue red green) msymbol(D S T) lwidth(*2 *2 *2) `base0'
local base4 mcol(blue red green maroon) mfcol(blue*0.25 red*0.25 green*0.25 maroon*0.25) mlcol(blue red green maroon) lcol(blue red green maroon) msymbol(D S T O) lwidth(*2 *2 *2 *2) `base0'
local base5 mcol(blue red green maroon navy) mfcol(blue*0.25 red*0.25 green*0.25 maroon*0.25 navy*0.25) mlcol(blue red green maroon navy) lcol(blue red green maroon navy) msymbol(D S T O X) lwidth(*2 *2 *2 *2 *2) `base0'

local sbase1 mcol(blue) mfcol(blue*0.25) mlcol(blue) lcol(blue) msymbol(D) lwidth(*2)
local sbase2 mcol(red) mfcol(red*0.25) mlcol(red) lcol(red) msymbol(S) lwidth(*2)
local sbase3 mcol(green) mfcol(green*0.25) mlcol(green) lcol(green) msymbol(T) lwidth(*2)
local sbase4 mcol(maroon) mfcol(maroon*0.25) mlcol(maroon) lcol(maroon) msymbol(O) lwidth(*2)
local sbase5 mcol(navy) lcol(navy) msymbol(X) lwidth(*2)

// xlabel (medlarge, large, vlarge, huge, vhuge etc)
local empxlabel xlabel(1 "[5,10)" 2 "[10,20)" 3 "[20,100)" 4 "[100,1000)" 5 "≥1000", labsize(medlarge) grid)
local lpxlabel xlabel(, labsize(medlarge) grid)

// xtitle
local empxtitle xtitle("Employment", size(medlarge))
local lpxtitle xtitle("Log Labor Productivity Residual Quintile", size(medlarge))

local dempxtitle  xtitle("Average Employment Growth by Decile", size(medlarge))
local dlpxtitle xtitle("Average Labor Productivity Residual Growth by Decile", size(medlarge))

local permempxtitle xtitle("Permanent Employment", size(medlarge))
local permlpxtitle xtitle("Log Permanent Labor Productivity Residual Quintile", size(medlarge))


// ytitle
local meanyleveltitle ytitle("Average of {&epsilon}{sub:it}", size(medlarge))
local meanytitle ytitle("Average of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))
local p9010ytitle ytitle("P90-P10 of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))
local p9050ytitle ytitle("P90-P50 of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))
local p5010ytitle ytitle("P50-P10 of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))

local dispersionytitle ytitle("Dispersion of {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge))

local fracytitle ytitle("Fraction of Dropout Workers", size(medlarge))

local meanemptitle ytitle("Average Employment Growth", size(medlarge))

// legend
local sexlegend legend(order(1 "All" 2 "Male" 3 "Female") row(1) region(lcolor(white)) size(medlarge))

local dispersionlegend legend(order(1 "P90-P50" 2 "P50-P10") row(1) region(lcolor(white)) size(medlarge))

local yearlegend legend(order(1 "Years 2001–2007" 2 "Years 2008–2011" 3 "Years 2012–2016") region(lcolor(white)) size(medlarge))
local agelegend legend(order(1 "Worker Ages 25–34" 2 "Worker Ages 35–44" 3 "Worker Ages 45–55") row(1) region(lcolor(white)) size(medlarge))
local entagelegend legend(order(1 "Firm Ages <10" 2 "Firm Ages 10–19" 3 "Firm Ages ≥20") region(lcolor(white)) size(medlarge))

local mover1legend legend(order(1 "Stayer" 2 "Non-laid-off Mover" 3 "Laid-off Mover") row(1) region(lcolor(white)) size(medlarge))

local emplegend legend(order(1 "[5,10)" 2 "[10,20)" 3 "[20,100)" 4 "[100,1000)" 5 "≥1000") row(2) region(lcolor(white)) size(medlarge))
local lplegend legend(order(1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Q5") row(1) region(lcolor(white)) size(medlarge))
local permearnlegend legend(order(1 "Q1" 2 "Q2" 3 "Q3" 4 "Q4" 5 "Q5") row(1) region(lcolor(white)) size(medlarge))
local top_permearnlegend legend(order(1 "[P80,P90)" 2 "[P90,P99)" 3 "≥P99") row(1) region(lcolor(white)) size(medlarge))

local demplegend legend(order(1 "Low Employment Growth" 2 "Middle Employment Growth" 3 "High Employment Growth") region(lcolor(white)) size(medlarge))
local dlplegend legend(order(1 "Low Productivity Growth" 2 "Middle Productivity Growth" 3 "High Productivity Growth") region(lcolor(white)) size(medlarge))

// start
//____________________________________________________________________________
capture log close

log using $log/multivariate.log, replace

local v emp
local g all
local h 1
local y d`h'logearn_res

use $cleaned/workers_firms, clear

// decile of permanent earnings
//______________________________________
drop permearn_group_all
sort year logpermearn_res
by year: gen rank=_n if logpermearn_res!=.
by year: egen obs=max(rank)
gen qtile=rank/obs if obs!=.

gen permearn_group_all=.
replace permearn_group_all=1 if qtile>=0 & qtile<=0.1
replace permearn_group_all=2 if qtile>0.1 & qtile<=0.2
replace permearn_group_all=3 if qtile>0.2 & qtile<=0.3
replace permearn_group_all=4 if qtile>0.3 & qtile<=0.4
replace permearn_group_all=5 if qtile>0.4 & qtile<=0.5
replace permearn_group_all=6 if qtile>0.5 & qtile<=0.6
replace permearn_group_all=7 if qtile>0.6 & qtile<=0.7
replace permearn_group_all=8 if qtile>0.7 & qtile<=0.8
replace permearn_group_all=9 if qtile>0.8 & qtile<=0.9
replace permearn_group_all=10 if qtile>0.9 & qtile!=.

drop rank obs qtile

// firm age groups
replace entage_group=entage
replace entage_group=0 if entage_group<0
replace entage_group=30 if entage_group>30 & entage_group!=.

// now keep only those with non-missing earnings growth
keep if `v'_group!=. & logearn_res!=. 
local y d`h'logearn_res
drop if `y'==.

sort pid year
xtset pid year
gen qt=L.permearn_group_all

// run regression
reg `y' i.d`h'logemp_group i.emp_group i.entage_group

// need to create two excel files to save these coefficients for plotting

// effect of firm size (Figure S35(a))
//________________________________________
local filename reg_`y'_by_`v'_level_`g'
import excel $output/`filename', firstrow clear

twoway (connected avg reg `v'_group, `base2' ``v'xlabel' ``v'xtitle' ytitle("Average Effect on {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge)) legend(order(1 "Average Conditional on Employment Only" 2 "Multivariate Linear Regression") row(2) region(lcolor(white)) size(medlarge)))

graph export $output/`filename'.pdf, replace

// effect of firm growth (Figure S35(b))
//________________________________________
local x d`h'log`v'
local filename reg_`y'_by_`v'_growth`h'_`g'
import excel $output/`filename', firstrow clear

twoway (connected avg reg `x', `base3' `d`v'xtitle' ytitle("Average Effect on {&Delta}{sup:1}{&epsilon}{sub:it}", size(medlarge)) legend(order(1 "Average Conditional on Employment Growth Only" 2 "Multivariate Linear Regression") row(2) region(lcolor(white)) size(medlarge)))

graph export $output/`filename'.pdf, replace

capture log close


