capture log close

log using $log/select.log, replace

local varlist year birth_year entid_syn personid sex t4earn totearn_p1 pd7_avgemp_12 total_revenue net_income_9369 t4_payroll naics_scan perm_reason_1_inclclx bus_birth_year flag_main incorporated

scalar minwage2001=5.5
scalar minwage2002=5.9
scalar minwage2003=5.9
scalar minwage2004=5.9
scalar minwage2005=6.25
scalar minwage2006=6.7
scalar minwage2007=7.25
scalar minwage2008=7.75
scalar minwage2009=8
scalar minwage2010=8
scalar minwage2011=9.4
scalar minwage2012=9.75
scalar minwage2013=9.95
scalar minwage2014=10.2
scalar minwage2015=10.3
scalar minwage2016=10.5

scalar cpi2001=97.8
scalar cpi2002=100
scalar cpi2003=102.8
scalar cpi2004=104.7
scalar cpi2005=107
scalar cpi2006=109.1
scalar cpi2007=111.5
scalar cpi2008=114.1
scalar cpi2009=114.4
scalar cpi2010=116.5
scalar cpi2011=119.9
scalar cpi2012=121.7
scalar cpi2013=122.8
scalar cpi2014=125.2
scalar cpi2015=126.6
scalar cpi2016=128.4
scalar cpi2018=133.4

// read
//___________________________
forval y=$min_year/$max_year{

	use `varlist' using $raw/data_wf_`y', clear
	
	gen age=year-birth_year+1
	keep if inrange(age,$min_age,$max_age)
	
	compress
	save $cleaned/data_wf_`y'_restricted, replace

}

// append
//___________________________
clear
forval y=$min_year/$max_year{
	append using $cleaned/data_wf_`y'_restricted
	erase $cleaned/data_wf_`y'_restricted.dta
}
compress
save $cleaned/appended, replace

// start cleaning
//___________________________
replace perm_reason_1_inclclx=0 if perm_reason_1_inclclx==.

ren personid pid
ren entid_syn entid

// save layoff records for all jobs
preserve
keep year pid entid perm_reason_1_inclclx
ren perm_reason_1_inclclx layoff
keep if layoff==1
duplicates drop
sort pid year entid
compress
save $cleaned/layoffs, replace
restore

// keep only main job
//______________________________________
drop perm_reason_1_inclclx
keep if flag_main==1

// randomly select if there are still multiple jobs
by pid year, sort: gen n=_n
by pid year, sort: gen N=_N

gen aux=runiform() if n==1

by pid year, sort: egen aux2=mean(aux)
replace aux=aux2*N
replace aux=ceil(aux)

keep if n==aux
drop aux* n N

// sample selection based on main job
//___________________________________________________________
keep if incorporated==1 & pd7_avgemp_12>=5 & pd7_avgemp_12!=.
drop incorporated

destring naics_scan, gen(naics6) 
drop naics_scan

drop if naics6 >= 610000 & naics6 < 619999
drop if naics6 >= 620000 & naics6 < 629999
drop if naics6 >= 910000 & naics6 < 919999

// deflation
//___________________________________________________________
gen above=0
gen above2=0 // will be used for log earnings growth

forval y=$min_year/$max_year{
	replace above=1 if totearn_p1>=minwage`y'*260 & totearn_p1!=. & year==`y'
	replace above2=1 if totearn_p1>=minwage`y'*260/3 & totearn_p1!=. & year==`y'
	
	foreach v in totearn_p1 t4earn t4_payroll total_revenue net_income_9369 {
		replace `v' = `v'/(cpi`y'/cpi2018) if year == `y'
	}
}

gen all=1
gen male=(sex==1)
gen female=(sex==2)

sort pid year

compress
save $cleaned/selected, replace
erase $cleaned/appended.dta

// add layoffs
//___________________________________________________________
use $cleaned/layoffs, clear

// merge with worker data: layoff in the same year
ren layoff F0layoff
merge 1:1 pid year entid using $cleaned/selected, keep(match using)
drop _merge
compress
save $cleaned/selected, replace

// merge with worker data: layoff in the next year
use $cleaned/layoffs, clear

replace year=year-1
ren layoff F1layoff

merge 1:1 pid year entid using $cleaned/selected, keep(match using)
drop _merge

replace F0layoff=0 if F0layoff==. & year<$max_year
replace F1layoff=0 if F1layoff==. & year<$max_year-1 & age<$max_age

ren pid personid
ren entid entid_syn

// destring ID variables
egen pid = group(personid)
egen entid = group(entid_syn)

sort pid year
xtset pid year

gen L1F1layoff=L1.F1layoff

// laid off from this year's main job in this year or next year 
gen layoff_this_job=(F0layoff==1 | F1layoff==1) if F0layoff!=. & F1layoff!=.

// laid off from this or previous year's main job in this year 
gen layoff_this_year=(F0layoff==1 | L1F1layoff==1) if (F0layoff!=. & L1F1layoff!=.)

sort pid year

compress
save $cleaned/selected, replace
erase $cleaned/layoffs.dta

log close
