capture log close
log using $log/stats.log, replace

// summary stats: restricted sample, by year
//______________________________________________
local varlist year pid female age earn entid emp logearn_res

use `varlist' if logearn_res!=. & entid!=. using $cleaned/workers_firms, clear

// number of firms
by entid year, sort: gen count_firm=_n==1

// number of workers
gen count_worker=1

// firm-level average of size
by entid year, sort: replace emp=. if _n!=1

collapse (mean) emp age earn female (sum) count_firm count_worker, by(year)
export excel $output/stats_by_year_restricted_sample, firstrow(variables) replace

// summary stats: restricted sample, all years
//______________________________________________
local varlist d1logearn_res d1logemp lp d1loglp stayer1 layoff_this_job logearn_res entid year mover1

use `varlist' if logearn_res!=. & entid!=. using $cleaned/workers_firms, clear

gen missing_earnings_growth=(d1logearn_res==.)
gen missing_emp_growth=(d1logemp==.)
gen missing_lp=(lp==.)
gen missing_lp_growth=(d1loglp==.)

foreach v in emp_growth lp lp_growth {
	gen missing_`v'_by_firm=missing_`v'
	by entid year, sort: replace missing_`v'_by_firm=. if _n!=1
}

// mover1 is missing when lay off is not defined (year 2015)
gen stayer=(mover1==0) if d1logearn_res!=. & mover1!=.
gen non_laid_off_mover=(mover1==1) if d1logearn_res!=. & mover1!=.
gen laid_off_mover=(mover1==2) if d1logearn_res!=. & mover1!=.

preserve
local varlist missing_earnings_growth missing_emp_growth missing_lp missing_lp_growth missing_emp_growth_by_firm missing_lp_by_firm missing_lp_growth_by_firm d1logearn_res stayer non_laid_off_mover laid_off_mover
collapse (mean) `varlist'
export excel $output/stats_all_years_restricted_sample, firstrow(variables) replace
restore

local varlist d1logearn_res stayer non_laid_off_mover laid_off_mover

preserve
keep if d1logemp!=.
collapse (mean) `varlist'
export excel $output/stats_all_years_restricted_sample_nonmissing_emp_growth, firstrow(variables) replace
restore

preserve
keep if d1loglp!=.
collapse (mean) `varlist'
export excel $output/stats_all_years_restricted_sample_nonmissing_lp_growth, firstrow(variables) replace
restore

// summary stats: full sample, by year
//_______________________________________________________________
local varlist year personid birth_year sex totearn_p1 entid_syn pd7_avgemp_12 flag_main

// calculate stats by year
//___________________________
clear
forval y=$min_year/$max_year{

    use `varlist' using $raw/data_wf_`y', clear
    gen age=year-birth_year+1
    keep if inrange(age,$min_age,$max_age) & flag_main==1
    drop flag_main birth_year

    ren personid pid
    ren entid_syn entid
    ren pd7_avgemp_12 emp
    ren totearn_p1 earn    
    gen female=(sex==2)

    replace earn=. if earn<minwage`y'*260
    replace earn=earn/(cpi`y'/cpi2018)
    
    // randomly select main job if there are still multiple jobs
    //____________________________________________________________
	sort pid
    by pid: gen n=_n
    by pid: gen N=_N

    gen aux=runiform() if n==1

    by pid, sort: egen aux2=mean(aux)
    replace aux=aux2*N
    replace aux=ceil(aux)

    keep if n==aux
    drop aux* n N

    // start calculating stats
    //____________________________________________________________    
    drop if earn==. | emp==.

    // number of firms
    by entid, sort: gen count_firm=_n==1

    // number of workers
    gen count_worker=1

	// firm-level average of size
	by entid year, sort: replace emp=. if _n!=1
	
    collapse (mean) emp age earn female (sum) count_firm count_worker
    save $output/stats_by_year_full_sample_`y', replace
}

// merge all years
//___________________________
clear
gen year=.
forval y=$min_year/$max_year{
    append using $output/stats_by_year_full_sample_`y'
	replace year=`y' if year==.
}
export excel $output/stats_by_year_full_sample, firstrow(variables) replace

capture log close
