capture log close
log using $log/workers.log, replace

use $cleaned/selected, clear

// keep only worker variables
//______________________________________
keep year pid entid age sex totearn_p1 above* all male female layoff*

// rename 
//______________________________________
rename totearn_p1 earn

// construct permanent earnings
//______________________________________
sort pid year
xtset pid year

forval i=1/2{
	gen L`i'earn=L`i'.earn
	replace L`i'earn=0 if L`i'earn==.
	
	gen L`i'above=L`i'.above
	replace L`i'above=0 if L`i'above==.
	
	gen L`i'nonmissing=(L`i'.earn!=.)
}

gen permearn=(earn+L1earn+L2earn)/(1+L1nonmissing+L2nonmissing)
gen n_above=above+L1above+L2above
replace permearn=. if n_above<2 | year<$min_year+2 | age<$min_age+2

drop n_* L*

// residuals
//______________________________________
gen logearn=log(earn) if above==1
gen logearn2=log(earn) if above2==1
gen logpermearn=log(permearn)

foreach v in earn earn2 permearn {
	reghdfe log`v', absorb(i.sex#i.year#i.age) residuals(log`v'_res)
}
reghdfe layoff_this_job, absorb(i.sex#i.year#i.age) residuals(layoff_res)

// within-firm percentile
//______________________________________
sort year entid logpermearn_res
by year entid: gen rank=_n if logpermearn_res!=.
by year entid: egen obs=max(rank)
gen qtile=rank/obs if obs>=10 & obs!=.

gen permearn_group=.
replace permearn_group=1 if qtile>=0 & qtile<=0.2
replace permearn_group=2 if qtile>0.2 & qtile<=0.4
replace permearn_group=3 if qtile>0.4 & qtile<=0.6
replace permearn_group=4 if qtile>0.6 & qtile<=0.8
replace permearn_group=5 if qtile>0.8 & qtile!=.


replace qtile=. if obs<100

gen top_permearn_group=.
replace top_permearn_group=1 if qtile>0.8 & qtile<=0.9
replace top_permearn_group=2 if qtile>0.9 & qtile<=0.99
replace top_permearn_group=3 if qtile>0.99 & qtile!=.

drop rank obs qtile

// define growth and other dynamic variables
//______________________________________
sort pid year
xtset pid year

gen d1logearn_res=F1.logearn2_res-logearn_res
gen d5logearn_res=F5.logearn2_res-logearn_res

gen stayer1=(F1.entid==entid) if age<=$max_age-1 & year<=$max_year-1

gen mover1=.
replace mover1=0 if stayer1==1
replace mover1=1 if stayer1==0 & layoff_this_job==0 // volutary separation
replace mover1=2 if stayer1==0 & layoff_this_job==1 // involutary separation

gen stayer5=(F5.entid==entid) if age<=$max_age-5 & year<=$max_year-5
gen mover5=.
replace mover5=0 if stayer5==1
replace mover5=1 if stayer5==0


// other group definitions
//______________________________________
gen year_group=.
replace year_group=1 if inrange(year,2001,2007)
replace year_group=2 if inrange(year,2008,2011)
replace year_group=3 if inrange(year,2012,2016)
	
gen age_group=.
replace age_group=1 if inrange(age,25,34)
replace age_group=2 if inrange(age,35,44)
replace age_group=3 if inrange(age,45,55)

compress
save $cleaned/workers, replace

log close

